# -*- coding: UTF-8 -*-

__revision__ = '$Id: widgets.py 1040 2008-11-15 21:13:49Z mikej06 $'

# Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gtk
import sys

def define_widgets(self, gladefile):
	get = lambda x: gladefile.get_widget(x)
	self.widgets = {}
	
	self.widgets['window'] = get('main_window')
	self.widgets['window'].connect('key_press_event', self.on_key_press_event)
	self.widgets['treeview'] = get('main_treeview')
	self.widgets['treeview'].connect('button_press_event', self.on_maintree_button_press_event)
	self.widgets['statusbar'] = get('statusbar')
	self.widgets['progressbar']    = get('w_progress')	# get from web
	#buttons
	self.widgets['new_db']      = get('new_bt')
	self.widgets['toolbar'] = get('toolbar1')
	

	self.widgets['movie'] = {#{{{
		'cast':			get('m_cast'),
		'classification':	get('m_classification'),
		'collection':		get('m_collection'),
		'color':		get('m_color'),
		'condition':		get('m_condition'),
		'country':		get('m_country'),
		'director':		get('m_director'),
		'genre':		get('m_genre'),
		'imdb':			get('m_imdb'),
		'layers':		get('m_layers'),
		'loan_info':		get('loan_information'),
		'medium':		get('m_medium'),
		'notes':		get('m_notes'),
		'number':		get('m_number'),
		'o_title':		get('m_o_title'),
		'picture':		get('m_picture_image'),
		'picture_button':	get('m_picture'),
		'plot':			get('m_plot'),
		'region':		get('m_region'),
		'runtime':		get('m_runtime'),
		'seen_icon':		get('m_seen_icon'),
		'site':			get('m_site'),
		'studio':		get('m_studio'),
		'tags':			get('m_tags'),
		'title':		get('m_title'),
		'trailer':		get('m_trailer'),
		'vcodec':		get('m_vcodec'),
		'volume':		get('m_volume'),
		'year':			get('m_year'),
		'audio_vbox':		get('m_audio_vbox'),
		'subtitle_vbox':	get('m_subtitle_vbox'),
		'show_collection_button':get('m_show_collection_button'),
		'show_volume_button':	get('m_show_volume_button'),
		'go_o_site_button':	get('go_o_site'),
		'go_site_button':	get('go_site'),
		'go_trailer_button':	get('go_trailer'),
		'return_button':	get('return_button'),
		'loan_button':		get('loan_button'),
		'loan_history':		get('loan_history'),
		'loan_to':		get('loan_to'),
		'email_reminder_button':get('b_email_reminder'),
		'image_rating':		get('m_image_rating'),
	}
	get('m_seen_icon_eventbox').connect('button_press_event', self.on_m_seen_icon_button_press_event)
	#}}}

	self.widgets['add'] = {#{{{
		'window':	get('add_movie'),
		'notebook':	get('notebook_add'),
		'classification':get('am_classification'),
		'collection':	get('am_collection_combo'),
		'color':	get('am_color'),
		'condition':	get('am_condition'),
		'country':	get('am_country'),
		'director':	get('am_director'),
		'discs':	get('am_discs'),
		'genre':	get('am_genre'),
		'site':		get('am_imdb'),
		'layers':	get('am_layers'),
		'media':	get('am_media'),
		'medium_vbox':	get('am_medium_vbox'),
		'number':	get('am_number'),
		'notes':	get('am_obs'),
		'o_title':	get('am_original_title'),
		'picture':	get('am_image'),
		'image':	get('am_hide_image_name'),
		'plot':		get('am_plot'),
		'plugin_desc':	get('am_plugin_desc'),
		'plugin_image':	get('am_plugin_image'),
		'region':	get('am_region'),
		'runtime':	get('am_runtime'),
		'seen':		get('am_seen'),
		'o_site':	get('am_site'),
		'source':	get('am_source'),
		'studio':	get('am_studio'),
		'tag_vbox':	get('am_tag_vbox'),
		'title':	get('am_title'),
		'trailer':	get('am_trailer'),
		'vcodec':	get('am_vcodec'),
		'volume':	get('am_volume_combo'),
		'cast':		get('am_with'),
		'year':		get('am_year'),
		'image_rating': get('image_add_rating'),
		'rating_slider':get('rating_scale_add'),
		'lang_menu':	get('lang_menu'),
		'lang_treeview':get('lang_treeview'),
		'b_get_from_web':get('get_from_web'),
		'c_web_source':	get('combo_source'), # c_web_source
		'delete_poster': get('delete_poster'),
		'add_button':	get('am_add_button'),
		'add_close_button':get('am_add_close_button'),
		'clear_button':	get('am_clear_button'),
		'save_button':	get('am_save_button'),
		'cb_only_empty':get('am_cb_only_empty'),
	}
	self.widgets['add']['window'].connect('delete_event', self.on_delete_event_am)
	self.widgets['add']['lang_treeview'].connect('button_press_event', self.on_lang_treeview_button_press_event)
	self.widgets['add']['o_title'].connect('activate', self.on_enter)
	self.widgets['add']['title'].connect('activate', self.on_enter)
	self.widgets['add']['window'].set_transient_for(self.widgets['window'])
	#}}}

	self.widgets['preferences'] = {#{{{
		'window':		get('w_preferences'),
		'treeview':		get('p_treeview'),
		'color':		get('p_color'),
		'condition':		get('p_condition'),
		'db_details':		get('p_db_details'),
		'db_host':		get('p_db_host'),
		'db_name':		get('p_db_name'),
		'db_passwd':		get('p_db_passwd'),
		'db_port':		get('p_db_port'),
		'db_type':		get('p_db_type'),
		'db_user':		get('p_db_user'),
		'epdf_reader':		get('pdf_reader_entry'),
		'font':			get('p_font'),
		'layers':		get('p_layers'),
		'media':		get('p_media'),
		'region':		get('p_region'),
		's_classification':	get('p_s_classification'),
		's_country':		get('p_s_country'),
		's_director':		get('p_s_director'),
		's_genre':		get('p_s_genre'),
		's_image':		get('p_s_image'),
		's_notes':		get('p_s_notes'),
		's_o_site':		get('p_s_o_site'),
		's_o_title':		get('p_s_o_title'),
		's_plot':		get('p_s_plot'),
		's_rating':		get('p_s_rating'),
		's_runtime':		get('p_s_runtime'),
		's_site':		get('p_s_site'),
		's_studio':		get('p_s_studio'),
		's_title':		get('p_s_title'),
		's_trailer':		get('p_s_trailer'),
		's_cast':		get('p_s_cast'),
		's_year':		get('p_s_year'),
		's_limit':		get('p_sp_s_limit'),
		'vcodec':		get('p_vcodec'),
		'view_image':		get('view_image'),
		'view_number':		get('view_number'),
		'view_o_title':		get('view_otitle'),
		'view_title':		get('view_title'),
		'view_director':	get('view_director'),
		'view_genre':	get('view_genre'),
		'view_seen':	get('view_seen'),
		'view_year':	get('view_year'),
		'view_runtime':	get('view_runtime'),
		'view_rating':	get('view_rating'),
		'rating_image':		get('rating_image'),
		'spellchecker':		get('spellchecker_pref'),
		'spell_notes':		get('spell_notes'),
		'spell_plot':		get('spell_plot'),
		'spell_lang':		get('spell_lang'),
		'vbox_spellchecker':	get('vbox_spellchecker'),
		'default_plugin':	get('default_plugin'),
		'mail_smtp_server':	get('mail_smtp_server'),
		'mail_use_auth':	get('mail_use_auth'),
		'mail_username':	get('mail_username'),
		'mail_password':	get('mail_password'),
		'mail_email':		get('mail_email'),
		'mail_smtp_port':		get('mail_smtp_port'),
		'mail_use_tls':		get('mail_use_tls'),
		'lang_name':		get('lang_name_combo'),
		'tag_name':		get('tag_name_combo'),
		'acodec_name':		get('acodec_name_combo'),
		'achannel_name':	get('achannel_name_combo'),
		'subformat_name':	get('subformat_name_combo'),
		'medium_name':		get('medium_name_combo'),
		'vcodec_name':		get('vcodec_name_combo'),
		'sortby':		get('p_sortby'),
		'sortby_reverse':	get('p_sortby_reverse'),
		'amazon_locale':	get('cb_amazon_locale'),
	}
	self.widgets['preferences']['treeview'].connect('button_press_event', self.on_p_tree_button_press_event)
	self.widgets['preferences']['window'].connect('delete_event', self.on_delete_event_p)
	self.widgets['preferences']['spellchecker'].connect('toggled', self.on_cb_spellchecker_pref_toggled)
	self.widgets['preferences']['window'].set_transient_for(self.widgets['window'])
	#}}}

	self.widgets['results'] = {#{{{
		'window':	get('results'),
		'treeview':	get('results_treeview'),
		'select':	get('results_select'),
		'cancel':	get('results_cancel'),
	}
	self.widgets['results']['window'].connect('delete_event', self.on_delete_event_r)
	self.widgets['results']['window'].set_transient_for(self.widgets['add']['window'])
	# default results window signals:
	self.results_signal = self.widgets['results']['select'].connect('clicked', self.populate_dialog_with_results)
	self.results_double_click = self.widgets['results']['treeview'].connect('button_press_event', self.on_results_button_press_event)
	#}}}

	self.widgets['print_cover'] = {#{{{
		# TODO: merge these two windows
		'window_simple':	get('w_print_cover_simple'),
		'window_image':		get('w_print_cover_image'),
		'cs_size':		get('cover_simple_size'),
		'cs_include_movie_number':get('cover_simple_include_movie_number'),
		'cs_include_poster':	get('cover_simple_include_poster'),
		'ci_size':		get('cover_image_size'),
		'ci_number':		get('cover_image_number'),
	}
	self.widgets['print_cover']['window_simple'].connect('delete_event', self.on_delete_event_pcs)
	self.widgets['print_cover']['window_image'].connect('delete_event', self.on_delete_event_pci)
	self.widgets['print_cover']['window_simple'].set_transient_for(self.widgets['window'])
	self.widgets['print_cover']['window_image'].set_transient_for(self.widgets['window'])
	#}}}
	
	self.widgets['people'] = {#{{{
		'window':	get('w_people'),
		'treeview':	get('p_treeview'),
	}
	self.widgets['people']['window'].connect('delete_event', self.on_delete_event_wp)
	self.widgets['people']['window'].set_transient_for(self.widgets['window'])
	#}}}
	
	self.widgets['person'] = {#{{{
		# TODO: merge these two windows
		'window':	get('w_add_person'),
		'e_window':	get('w_edit_person'),
		'name':		get('ap_name'),
		'email':	get('ap_email'),
		'phone':	get('ap_phone'),
		'e_name':	get('ep_name'),
		'e_email':	get('ep_email'),
		'e_phone':	get('ep_phone'),
		'e_id':		get('ep_id'),
	}
	self.widgets['person']['window'].connect('delete_event', self.on_delete_event_ap)
	self.widgets['person']['e_window'].connect('delete_event', self.on_delete_event_ep)
	self.widgets['person']['window'].set_transient_for(self.widgets['people']['window'])
	self.widgets['person']['e_window'].set_transient_for(self.widgets['people']['window'])
	#}}}

	self.widgets['filter'] = {#{{{
		'text':		get('filter_txt'),
		'criteria':	get('filter_criteria'),
		'collection':	get('f_col'),
		'volume':	get('f_volume'),
		'loanedto':	get('f_loanedto'),
		'tag':	get('f_bytag'),
	}#}}}
	
	self.widgets['menu'] = {#{{{
		'toolbar':	get('menu_toolbar'),
		'export':	get('export_menu'),
		'import':	get('import_menu'),
		'not_seen_movies':	get('seen_movies'),
		'loaned_movies':get('loaned_movies'),
		'all_movies':	get('all_movies'),
		'delete_poster': get('t_delete_poster'),
		'loan':		get('loan1'),
		'email':	get('return1'),
		'return':	get('e-mail_reminder1'),
	}#}}}
	
	self.widgets['popups'] = {#{{{
		'main':		get('popup'),
		'loan':		get('popup_loan'),
		'return':	get('popup_return'),
		'email':	get('popup_email'),
	}#}}}
	
	self.widgets['w_loan_to']     = get('w_loan_to')
	self.widgets['w_loan_to'].connect('delete_event', self.on_delete_event_lt)

	self.widgets['poster_window'] = get('poster_window')
	self.widgets['poster_window'].connect('delete_event', self.on_delete_event_pw)
	self.widgets['poster_window'].set_transient_for(self.widgets['window'])
	self.widgets['big_poster']    = get('big_poster')

	#add some tooltips
	self.widgets['tooltips'] = gtk.Tooltips()
	self.widgets['tooltips'].set_tip(self.widgets['preferences']['epdf_reader'], _('Define here the PDF reader you want to use within Griffith. Popular choices are xpdf, gpdf, evince or kpdf. Make sure you have this program installed and working first.'))
	self.widgets['tooltips'].set_tip(self.widgets['preferences']['spell_lang'], _("Here you can define the desired language to use while spell checking some fields. Use you locale setting. For example, to use european portuguese spell checking enter 'pt'"))
	self.widgets['tooltips'].set_tip(self.widgets['preferences']['mail_smtp_server'], _("Use this entry to define the SMTP server you want to use to send e-mails. On *nix systems, 'localhost' should work. Alternatively, you can use your Internet Service Provider's SMTP server address."))
	self.widgets['tooltips'].set_tip(self.widgets['preferences']['mail_email'], _("This is the from e-mail address that should be used to all outgoing e-mail. You want to include your own e-mail address here probably."))
	self.widgets['tooltips'].set_tip(self.widgets['preferences']['mail_smtp_port'], _("Here you can define the smtp server port to use. If you want to use your gmail account service to send e-mails, try to enter '587' here. Default (and the most common one) is '25'"))
	self.widgets['tooltips'].set_tip(self.widgets['preferences']['mail_use_tls'], _("If you need TLS support, please check this checkbox. This is needed, for example, when using gmail service to send your reminder e-mails."))

	# define handlers for general events
	gladefile.signal_autoconnect({#{{{
		'gtk_main_quit'				: self.destroy,
		'on_window_state'			: self.on_window_state,
		'on_configure'				: self.on_configure,
		'on_about1_activate'			: self.about_dialog,
		'on_quit1_activate'			: self.destroy,
		'on_toolbar_quit_clicked'		: self.destroy,
		'on_toolbar_add_clicked'		: self.add_movie,
		'on_cancel_add_movie_clicked'		: self.hide_add_window,
		'on_add1_activate'			: self.add_movie,
		'on_add_movie_clicked'			: self.add_movie_db,
		'on_add_movie_close_clicked'		: self.add_movie_close_db,
		'on_delete_movie_clicked'		: self.delete_movie,
		'on_delete1_movie_activate'		: self.delete_movie,
		'on_main_treeview_row_activated'	: self.treeview_clicked,
		'on_row_activated'			: self.treeview_clicked,
		'on_get_from_web_clicked'		: self.get_from_web,
		'on_update_button_clicked'		: self.update_movie,
		'on_import_activate'			: self.on_import_activate,
		'on_seen_activate'			: self.toggle_seen,
		# preferences
		'on_preferences1_activate'		: self.show_preferences,
		'on_cancel_preferences_clicked'		: self.hide_preferences,
		'on_save_preferences_clicked'		: self.save_preferences,
		'on_p_db_type_changed'			: self.on_p_db_type_changed,
		'on_backup_activate'			: self.backup,
		'on_restore_activate'			: self.restore,
		'on_merge_activate'			: self.merge,
		'on_cover_simple_activate'		: self.print_cover_simple_show,
		'on_cancel_print_cover_simple_clicked'	: self.print_cover_simple_hide,
		'on_b_print_cover_simple_clicked'	: self.print_cover_simple_process,
		'on_add_clear_clicked'			: self.clear_add_dialog,
		'on_am_save_button_clicked'		: self.update_movie,
		'on_people_activate'			: self.show_people_window,
		'on_cancel_people_clicked'		: self.hide_people_window,
		'on_filter_txt_changed'			: self.filter_txt,
		'on_filter_criteria_changed'		: self.on_filter_criteria_changed,
		'on_clear_filter_clicked'		: self.clear_filter,
		'on_people_add_clicked'			: self.add_person,
		'on_add_person_cancel_clicked'		: self.add_person_cancel,
		'on_add_person_db_clicked'		: self.add_person_db,
		'on_people_delete_clicked'		: self.delete_person,
		'on_people_edit_clicked'		: self.edit_person,
		'on_edit_person_cancel_clicked'		: self.edit_person_cancel,
		'on_update_person_clicked'		: self.update_person,
		'on_clone_activate'			: self.clone_movie,
		'on_loan_button_clicked'		: self.loan_movie,
		'on_cancel_loan_clicked'		: self.cancel_loan,
		'on_loan_ok_clicked'			: self.commit_loan,
		'on_return_button_clicked'		: self.return_loan,
		'on_list_loaned_movies_activate'	: self.filter_loaned,
		'on_m_show_volume_button_clicked'	: self.show_volume,
		'on_m_show_collection_button_clicked'	: self.show_collection,
		'on_cover_choose_image_activate'	: self.print_cover_image,
		'on_cancel_print_cover_image_clicked'	: self.print_cover_image_hide,
		'on_b_print_cover_image_clicked'	: self.print_cover_image_process,
		'on_combo_source_changed'		: self.source_changed,
		# toolbar
		'on_view_toolbar_activate'		: self.toggle_toolbar,
		'on_go_first_clicked'			: self.go_first,
		'on_go_last_clicked'			: self.go_last,
		'on_go_back_clicked'			: self.go_prev,
		'on_go_forward_clicked'			: self.go_next,
		'on_new_bt_clicked'			: self.new_dbb,
		'on_new_activate'			: self.new_dbb,
		'on_edit_button_clicked'		: self.edit_movie,
		# poster
		'on_e_picture_clicked'			: self.change_poster,
		'on_open_poster_clicked'		: self.change_poster,
		'on_zoom_poster_clicked'		: self.z_poster,
		'on_delete_poster_clicked'		: self.del_poster,
		'on_fetch_poster_clicked'		: self.get_poster,
		# URLs
		'on_goto_homepage_activate'		: self.on_goto_homepage_activate,
		'on_goto_forum_activate'		: self.on_goto_forum_activate,
		'on_goto_report_bug_activate'		: self.on_goto_report_bug_activate,
		'on_go_o_site_clicked'			: self.go_oficial_site,
		'on_go_site_clicked'			: self.go_site,
		'on_go_trailer_clicked'			: self.go_trailer_site,
		'on_seen_movies_activate'		: self.filter_not_seen,
		'on_all_movies_activate'		: self.filter_all,
		'on_rating_scale_add_value_changed'	: self.scale_rating_change_add,
		'on_sugest_activate'			: self.sugest_movie,
		'on_popup_delete_activate'		: self.delete_movie,
		'on_popup_clone_activate'		: self.clone_movie,
		'on_popup_simple_activate'		: self.print_cover_simple_show,
		'on_popup_choose_image_activate'	: self.print_cover_image,
		# loans
		'on_popup_loan_activate'		: self.loan_movie,
		'on_popup_return_activate'		: self.return_loan,
		'on_popup_email_activate'		: self.email_reminder,
		'on_email_reminder_clicked'		: self.email_reminder,
		# volumes/collections
		'on_am_collection_combo_changed'	: self.on_am_collection_combo_changed,
		'on_am_volume_combo_changed'		: self.on_am_volume_combo_changed,
		'on_am_add_volume_button_clicked'	: self.add_volume,
		'on_am_add_collection_button_clicked'	: self.add_collection,
		'on_am_remove_volume_button_clicked'	: self.remove_volume,
		'on_am_remove_collection_button_clicked': self.remove_collection,
		'on_f_col_changed'			: self.filter_collection,
		'on_f_volume_changed'			: self.filter_volume,
		'on_f_loanedto_changed'			: self.filter_loanedto,
		'on_f_bytag_changed'			: self.filter_bytag,
		'on_results_cancel_clicked'		: self.results_cancel_ck,
		# languages
		'on_lang_add_clicked'			: self.on_lang_add_clicked,
		'on_lang_remove_clicked'		: self.on_lang_remove_clicked,
		'on_am_lang_add_clicked'		: self.on_am_lang_add_clicked,
		'on_am_lang_remove_clicked'		: self.on_am_lang_remove_clicked,
		'on_lang_rename_clicked'		: self.on_lang_rename_clicked,
		'on_lang_name_combo_changed'		: self.on_lang_name_combo_changed,
		# tags
		'on_tag_add_clicked'			: self.on_tag_add_clicked,
		'on_tag_remove_clicked'			: self.on_tag_remove_clicked,
		'on_tag_rename_clicked'			: self.on_tag_rename_clicked,
		'on_tag_name_combo_changed'		: self.on_tag_name_combo_changed,
		# audio codecs
		'on_acodec_add_clicked'			: self.on_acodec_add_clicked,
		'on_acodec_remove_clicked'		: self.on_acodec_remove_clicked,
		'on_acodec_rename_clicked'		: self.on_acodec_rename_clicked,
		'on_acodec_name_combo_changed'		: self.on_acodec_name_combo_changed,
		# audio channels
		'on_achannel_add_clicked'		: self.on_achannel_add_clicked,
		'on_achannel_remove_clicked'		: self.on_achannel_remove_clicked,
		'on_achannel_rename_clicked'		: self.on_achannel_rename_clicked,
		'on_achannel_name_combo_changed'	: self.on_achannel_name_combo_changed,
		# subtitle formats
		'on_subformat_add_clicked'		: self.on_subformat_add_clicked,
		'on_subformat_remove_clicked'		: self.on_subformat_remove_clicked,
		'on_subformat_rename_clicked'		: self.on_subformat_rename_clicked,
		'on_subformat_name_combo_changed'	: self.on_subformat_name_combo_changed,
		# media
		'on_medium_add_clicked'			: self.on_medium_add_clicked,
		'on_medium_remove_clicked'		: self.on_medium_remove_clicked,
		'on_medium_rename_clicked'		: self.on_medium_rename_clicked,
		'on_medium_name_combo_changed'		: self.on_medium_name_combo_changed,
		# video codecs
		'on_vcodec_add_clicked'			: self.on_vcodec_add_clicked,
		'on_vcodec_remove_clicked'		: self.on_vcodec_remove_clicked,
		'on_vcodec_rename_clicked'		: self.on_vcodec_rename_clicked,
		'on_vcodec_name_combo_changed'		: self.on_vcodec_name_combo_changed
	})#}}}

def reconnect_add_signals(self):#{{{
	self.widgets['add']['b_get_from_web'].set_sensitive(True)
	try:
		self.widgets['results']['select'].disconnect(self.poster_results_signal)
	except:
		pass

	try:
		self.widgets['results']['treeview'].disconnect(self.results_poster_double_click)
	except:
		pass

	# connect signals
	self.results_signal = self.widgets['results']['select'].connect('clicked', \
			self.populate_dialog_with_results)
	self.results_double_click = self.widgets['results']['treeview'].connect('button_press_event', \
		self.on_results_button_press_event)#}}}

def connect_poster_signals(self, event, result, current_poster):#{{{
	import edit

	try:
		self.widgets['results']['select'].disconnect(self.results_signal)
	except:
		pass

	try:
		self.widgets['results']['treeview'].disconnect(self.results_double_click)
	except:
		pass

	# connect signals

	self.results_poster_double_click = self.widgets['results']['treeview'].connect('button_press_event', \
		edit.get_poster_select_dc, self, result, current_poster)

	self.poster_results_signal = \
		self.widgets['results']['select'].connect('clicked', edit.get_poster_select, \
		self, result, current_poster)
	#}}}
# vim: fdm=marker



# -*- coding: UTF-8 -*-

__revision__ = '$Id: version.py 1040 2008-11-15 21:13:49Z mikej06 $'

# Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

pname        = "Griffith"
pversion     = "0.9.8"
pauthor      = "Vasco Nunes, Piotr Ożarowski <griffith-private@lists.berlios.de>"
pyear        = "2005-2008"
pwebsite     = "http://www.griffith.cc/"
pdescription = _("Griffith is a film collection manager.")



# -*- coding: UTF-8 -*-

__revision__ = '$Id: sql.py 1040 2008-11-15 21:13:49Z mikej06 $'

# Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

from sqlalchemy import *
import os.path
import gutils
import gtk

class DBTable(object):#{{{
	def __repr__(self):
		return "%s:%s" % (self.__class__.__name__, self.name)
	def add_to_db(self):
		if self.name is None or len(self.name)==0:
			debug.show("%s: name can't be empty" % self.__class__.__name__)
			return False
		# check if achannel already exists
		if self.get_by(name=self.name) is not None:
			debug.show("%s: '%s' already exists" % (self.__class__.__name__, self.name))
			return False
		debug.show("%s: adding '%s' to database..." % (self.__class__.__name__, self.name))
		self.save()
		try:
			self.flush()
		except exceptions.SQLError, e:
			debug.show("%s: add_to_db: %s" % (self.__class__.__name__, e))
			return False
		self.refresh()
		return True
	def remove_from_db(self):
		dbtable_id = self.__dict__[self.__class__.__name__.lower() + '_id']
		if dbtable_id<1:
			debug.show("%s: none selected => none removed" % self.__class__.__name__)
			return False
		tmp = None
		if hasattr(self,'movies'):
			tmp = getattr(self,'movies')
		elif hasattr(self,'movielangs'):
			tmp = getattr(self,'movielangs')
		if tmp and len(tmp)>0:
			gutils.warning(self, msg=_("This item is in use.\nOperation aborted!"))
			return False
		debug.show("%s: removing '%s' (id=%s) from database..."%(self.__class__.__name__, self.name, dbtable_id))
		self.delete()
		try:
			self.flush()
		except exceptions.SQLError, e:
			debug.show("%s: remove_from_db: %s" % (self.__class__.__name__, e))
			return False
		#self.refresh()
		return True
	def update_in_db(self):
		dbtable_id = self.__dict__[self.__class__.__name__.lower() + '_id']
		if dbtable_id<1:
			debug.show("%s: none selected => none updated" % self.__class__.__name__)
			return False
		if self.name is None or len(self.name)==0:
			debug.show("%s: name can't be empty" % self.__class__.__name__)
			return False
		tmp = self.get_by(name=self.name)
		if tmp is not None and tmp is not self:
			gutils.warning(self, msg=_("This name is already in use!"))
			return False
		self.update()
		try:
			self.flush()
		except exceptions.SQLError, e:
			debug.show("%s: update_in_db: %s" % (self.__class__.__name__, e))
			return False
		self.refresh()
		return True#}}}

class GriffithSQL:
	version = 2	# database format version, incrase after any changes in data structures
	metadata = None
	class Configuration(object):
		def __repr__(self):
			return "Config:%s=%s" % (self.param, self.value)
	class AChannel(DBTable):
		pass
	class ACodec(DBTable):
		pass
	class Collection(DBTable):
		pass
	class Lang(DBTable):
		pass
	class Medium(DBTable):
		pass
	class MovieLang(object):
		def __repr__(self):
			return "MovieLang:%s-%s (Type:%s ACodec:%s AChannel:%s SubFormat:%s)" % \
				(self.movie_id, self.lang_id, self.type, self.acodec_id, self.achannel_id, self.subformat_id)
	class MovieTag(object):
		def __repr__(self):
			return "MovieTag:%s-%s" % (self.movie_id, self.tag_id)
	class Person(DBTable):
		pass
	class SubFormat(DBTable):
		pass
	class Tag(DBTable):
		def remove_from_db(self):
			if len(self.movietags) > 0:
				gutils.warning(self, msg=_("This item is in use.\nOperation aborted!"))
				return False
			return DBTable.remove_from_db(self)
	class VCodec(DBTable):
		pass
	class Volume(DBTable):
		pass
	class Loan(object):#{{{
		def __repr__(self):
			return "Loan:%s (movie:%s person:%s)" % (self.loan_id, self.movie_id, self.person_id)
		def __setitem__(self, key, value):
			if key == 'movie_id' and value:
				if GriffithSQL.Movie.get_by(movie_id=value) is None:
					raise ValueError('wrong movie_id')
			elif key == 'person_id' and value:
				if GriffithSQL.Person.get_by(person_id=value) is None:
					raise ValueError('wrong movie_id')
			self[key] = value
		def _validate(self):
			if self.movie_id is None:
				raise ValueError('movie_id is not set')
			if self.person_id is None:
				raise ValueError('person_id is not set')
			if self.movie is None:
				self.movie = GriffithSQL.Movie.get_by(movie_id=self.movie_id)
				if self.movie is None:
					raise ValueError('wrong movie_id')
			if self.person is None:
				self.person = GriffithSQL.Person.get_by(person_id=self.person_id)
				if self.person is None:
					raise ValueError('wrong person_id')
			if self.collection_id>0 and self.collection is None:
				self.collection = GriffithSQL.Collection.get_by(collection_id=self.collection_id)
				if self.collection is None:
					raise ValueError('wrong collection_id')
			if self.volume_id>0 and self.volume is None:
				self.volume = GriffithSQL.Volume.get_by(volume_id=self.volume_id)
				if self.volume is None:
					raise ValueError('wrong volume_id')
			return True
		def set_loaned(self):
			"""
			Set loaned=True for all movies in volume/collection and for movie itself
			Set loan's date to today's date
			"""
			self._validate()

			if self.collection is not None:
				self.movie.mapper.mapped_table.update(self.movie.c.collection_id==self.collection_id).execute(loaned=True)
				self.collection.loaned = True
				self.collection.update()
			if self.volume is not None:
				self.movie.mapper.mapped_table.update(self.movie.c.volume_id==self.volume_id).execute(loaned=True)
				self.volume.loaned = True
				self.volume.update()
			if self.movie is None:
				self.movie = Movie.get_by(movie_id=self.movie_id)
			self.movie.loaned = True
			self.movie.update()
			if self.date is None:
				self.date = func.current_date()	# update loan date
			self.return_date = None
			self.save_or_update()
			try:
				self.mapper.get_session().flush()
				self.refresh()
			except exceptions.SQLError, e:
				debug.show("set_loaned: %s" % e)
				return False
			return True
		def set_returned(self):
			"""
			Set loaned=False for all movies in volume/collection and for movie itself.
			Set return_date to today's date
			"""
			self._validate()
			if self.collection is not None:
				self.movie.mapper.mapped_table.update(self.movie.c.collection_id==self.collection_id).execute(loaned=False)
				self.collection.loaned = False
				self.collection.update()
			if self.volume_id is not None:
				self.movie.mapper.mapped_table.update(self.movie.c.volume_id==self.volume_id).execute(loaned=False)
				self.volume.loaned = False
				self.volume.update()
			self.movie.loaned = False
			self.movie.update()
			if self.return_date is None:
				self.return_date = func.current_date()
			self.save_or_update()
			try:
				self.mapper.get_session().flush()
				self.refresh()
			except exceptions.SQLError, e:
				debug.show("set_returned: %s" % e)
				return False
			return True
			#}}}
	class Movie(object):#{{{
		def __repr__(self):
			return "Movie:%s (number=%s)" % (self.movie_id, self.number)
		def __setitem__(self, key, value):
			setattr(self,key,value)
		def __getitem__(self, key):
			return getattr(self,key)
		def has_key(self, key):
			if key in ('volume','collection','medium','vcodec','loans','tags','languages','lectors','dubbings','subtitles'):
				return True
			else:
				return self.c.has_key(key)
		def remove_from_db(self):
			if self.loaned == True:
				debug.show("You can't remove loaned movie!")
				return False
			self.delete()
			try:
				self.flush()
			except exceptions.SQLError, e:
				debug.show("remove_from_db: %s" % e)
				return False
			return True
		def update_in_db(self, t_movies=None):
			if self.movie_id < 1:
				raise ValueError('movie_id is not set')
			if t_movies is not None:
				self.languages.clear()
				self.tags.clear()
				#self.mapper.mapped_table.update(self.c.movie_id==t_movies['movie_id']).execute(t_movies)
			return self.add_to_db(t_movies)
		def add_to_db(self, t_movies=None):
			if t_movies is not None:
				t_tags = t_languages = None
				if t_movies.has_key('tags'):
					t_tags = t_movies.pop('tags')
				if t_movies.has_key('languages'):
					t_languages = t_movies.pop('languages')
				for i in self.c.keys():
					if t_movies.has_key(i):
						self[i] = t_movies[i]
				# languages
				if t_languages is not None:
					for lang in t_languages:
						if lang[0]>0:
							ml = GriffithSQL.MovieLang(lang_id=lang[0], type=lang[1],
								acodec_id=lang[2], achannel_id=lang[3], subformat_id=lang[4])
							self.languages.append(ml)
				# tags
				if t_tags is not None:
					for tag in t_tags.keys():
						self.tags.append(GriffithSQL.Tag(tag_id=tag))
			self.update()
			try:
				self.flush()
			except exceptions.SQLError, e:
				debug.show("add_to_db: %s" % e)
				if e.args[0][:16] == '(IntegrityError)':
					gutils.error(None, _('Column "%s" is not unique') % _('Number'))
				return False
			self.refresh()
			return True
		#}}}

	def __init__(self, config, gdebug, griffith_dir):
		from sqlalchemy.mods.threadlocal import assign_mapper
		from sqlalchemy.exceptions import InvalidRequestError
		global debug
		debug = gdebug
		if config.get('type', None, section='database') is None:
			config.set('type', 'sqlite', section='database')

		if config.get('type', 'sqlite', section='database') != 'sqlite':
			if config.get('host', None, section='database') is None:
				config.set('host', '127.0.0.1', section='database')
			if config.get('user', None, section='database') is None:
				config.set('user', 'griffith', section='database')
			if config.get('passwd', None, section='database') is None:
				config.set('passwd', 'gRiFiTh', section='database')
			if config.get('name', None, section='database') is None:
				config.set('name', 'griffith', section='database')

		# connect to database --------------------------------------{{{
		if config.get('type', section='database') == 'sqlite':
			url = "sqlite:///%s" % os.path.join(griffith_dir, config.get('name', 'griffith', section='database') + '.db')
		elif config.get('type', section='database') == 'postgres':
			if config.get('port', 0, section='database')==0:
				config.set('port', 5432, section='database')
			url = "postgres://%s:%s@%s:%d/%s" % (
				config.get('user', section='database'),
				config.get('passwd', section='database'),
				config.get('host', section='database'),
				int(config.get('port', section='database')),
				config.get('name', section='database'))
		elif config.get('type', section='database') == 'mysql':
			if config.get('port', 0, section='database')==0:
				config.set('port', 3306, section='database')
			url = "mysql://%s:%s@%s:%d/%s" % (
				config.get('user', section='database'),
				config.get('passwd', section='database'),
				config.get('host', section='database'),
				int(config.get('port', section='database')),
				config.get('name', section='database'))
		elif config.get('type', section='database') == 'mssql':
			if config.get('port', 0, section='database')==0:
				config.set('port', 1433, section='database')
			# use_scope_identity=0 have to be set as workaround for a sqlalchemy bug
			# but it is not guaranteed that the right identity value will be selected
			# because the select @@identity statement selects the very last id which
			# also can be a id from a trigger-insert or another user
			# sqlalchemy uses a wrong syntax. It has to select the id within the insert
			# statement: insert <table> (<columns>) values (<values>) select scope_identity()
			# (one statement !) After preparing and executing there should be a fetch
			# If it is executed as two separate statements the scope is lost after insert.
			url = "mssql://%s:%s@%s:%d/%s?use_scope_identity=0" % (
				config.get('user', section='database'),
				config.get('passwd', section='database'),
				config.get('host', section='database'),
				int(config.get('port', section='database')),
				config.get('name', section='database'))
		else:
			config.set('type', 'sqlite', section='database')
			url = "sqlite:///%s" % os.path.join(griffith_dir, config.get('name', 'griffith', section='database') + '.db')
		try:
			self.metadata = BoundMetaData(url)
		except Exception, e:	# InvalidRequestError, ImportError
			debug.show("BoundMetaData: %s" % e)
			config.set('type', 'sqlite', section='database')
			gutils.warning(self, "%s\n\n%s" % (_('Cannot connect to database.\nFalling back to SQLite.'), _('Please check debug output for more informations.')))
			self.metadata = BoundMetaData("sqlite:///%s" % os.path.join(griffith_dir, config.get('name', 'griffith', section='database') + '.db'))

		# try to establish a db connection
		try:
			self.metadata.engine.connect()
		except Exception, e:
			debug.show("engine connection: %s" % e)
			gutils.error(self, _('Database connection failed.'))
			config.set('type', 'sqlite', section='database')
			url = "sqlite:///%s" % os.path.join(griffith_dir, 'griffith.db')
			self.metadata = BoundMetaData(url)
			self.metadata.engine.connect()
		#}}}

		# prepare tables interface ---------------------------------{{{
		movies = Table('movies', self.metadata,
			Column('movie_id', Integer, primary_key = True),
			Column('number', Integer, nullable=False, unique=True),
			Column('collection_id', Integer, ForeignKey('collections.collection_id')),
			Column('volume_id', Integer, ForeignKey('volumes.volume_id')),
			Column('medium_id', Integer, ForeignKey('media.medium_id')),
			Column('vcodec_id', Integer, ForeignKey('vcodecs.vcodec_id')),
			Column('loaned', Boolean, nullable=False, default=False),
			Column('seen', Boolean, nullable=False, default=False),
			Column('rating', Smallinteger(2)),
			Column('color', Smallinteger),
			Column('cond', Smallinteger),	# MySQL will not accept name "condition"
			Column('layers', Smallinteger),
			Column('region', Smallinteger),
			Column('media_num', Smallinteger),
			Column('runtime', Integer),
			Column('year', Integer),
			Column('o_title', VARCHAR(255)),
			Column('title', VARCHAR(255)),
			Column('director', VARCHAR(255)),
			Column('o_site', VARCHAR(255)),
			Column('site', VARCHAR(255)),
			Column('trailer', VARCHAR(256)),
			Column('country', VARCHAR(128)),
			Column('genre', VARCHAR(128)),
			Column('image', VARCHAR(128)),
			Column('studio', VARCHAR(128)),
			Column('classification', VARCHAR(128)),
			Column('cast', TEXT),
			Column('plot', TEXT),
			Column('notes', TEXT))
		loans = Table('loans', self.metadata,
			Column('loan_id', Integer, primary_key=True),
			Column('person_id', Integer, ForeignKey('people.person_id'), nullable=False),
			Column('movie_id', Integer, ForeignKey('movies.movie_id'), nullable=False),
			Column('volume_id', Integer, ForeignKey('volumes.volume_id')),
			Column('collection_id', Integer, ForeignKey('collections.collection_id')),
			Column('date', Date, nullable=False, default=func.current_date()),
			Column('return_date', Date, nullable=True))
		people = Table('people', self.metadata,
			Column('person_id', Integer, primary_key=True),
			Column('name', VARCHAR(255), nullable=False, unique=True),
			Column('email', VARCHAR(128)),
			Column('phone', VARCHAR(64)))
		volumes = Table('volumes', self.metadata,
			Column('volume_id', Integer, primary_key=True),
			Column('name', VARCHAR(64), nullable=False, unique=True),
			Column('loaned', Boolean, nullable=False, default=False))
		collections = Table('collections', self.metadata,
			Column('collection_id', Integer, primary_key=True),
			Column('name', VARCHAR(64), nullable=False, unique=True),
			Column('loaned', Boolean, nullable=False, default=False))
		media = Table('media', self.metadata,
			Column('medium_id', Integer, primary_key=True),
			Column('name', VARCHAR(64), nullable=False, unique=True))
		languages = Table('languages', self.metadata,
			Column('lang_id', Integer, primary_key=True),
			Column('name', VARCHAR(64), nullable=False, unique=True))
		vcodecs = Table('vcodecs', self.metadata,
			Column('vcodec_id', Integer, primary_key=True),
			Column('name', VARCHAR(64), nullable=False, unique=True))
		acodecs = Table('acodecs', self.metadata,
			Column('acodec_id', Integer, primary_key=True),
			Column('name', VARCHAR(64), nullable=False, unique=True))
		achannels = Table('achannels', self.metadata,
			Column('achannel_id', Integer, primary_key=True),
			Column('name', VARCHAR(64), nullable=False, unique=True))
		subformats = Table('subformats', self.metadata,
			Column('subformat_id', Integer, primary_key=True),
			Column('name', VARCHAR(64), nullable=False, unique=True))
		tags = Table('tags', self.metadata,
			Column('tag_id', Integer, primary_key=True),
			Column('name', VARCHAR(64), nullable=False, unique=True))
		movie_lang = Table('movie_lang', self.metadata,
			Column('ml_id', Integer, primary_key=True),
			Column('type', Smallinteger), # 0: Original, 1:lector, 2:dubbing, 3:subtitle 
			Column('movie_id', Integer, ForeignKey('movies.movie_id'), nullable=False),
			Column('lang_id', Integer, ForeignKey('languages.lang_id'), nullable=False),
			Column('acodec_id', Integer, ForeignKey('acodecs.acodec_id')),
			Column('achannel_id', Integer, ForeignKey('achannels.achannel_id')),
			Column('subformat_id', Integer, ForeignKey('subformats.subformat_id')))
		movie_tag = Table('movie_tag', self.metadata,
			Column('mt_id', Integer, primary_key=True),
			Column('movie_id', Integer, ForeignKey('movies.movie_id')),
			Column('tag_id', Integer, ForeignKey('tags.tag_id')))
		configuration = Table('configuration', self.metadata,
			Column('param', VARCHAR(16), primary_key=True),
			Column('value', VARCHAR(128), nullable=False))#}}}

		# mappers -------------------------------------------------#{{{
		assign_mapper(self.Configuration, configuration)
		assign_mapper(self.Volume,volumes, properties={
			'movies': relation(self.Movie, backref='volume')})
		assign_mapper(self.Collection, collections, properties={
			'movies': relation(self.Movie, backref='collection')})
		assign_mapper(self.Medium, media, properties={
			'movies': relation(self.Movie, backref='medium')})
		assign_mapper(self.VCodec, vcodecs, properties={
			'movies': relation(self.Movie, backref='vcodec')})
		assign_mapper(self.Person, people, properties = {
			'loans'    : relation(self.Loan, backref='person', cascade='all, delete-orphan')})
		assign_mapper(self.MovieLang, movie_lang, primary_key=[movie_lang.c.ml_id], properties = {
			'movie'    : relation(self.Movie, lazy=False),
			'language' : relation(self.Lang, lazy=False),
			'achannel' : relation(self.AChannel),
			'acodec'   : relation(self.ACodec),
			'subformat': relation(self.SubFormat)})
		assign_mapper(self.ACodec, acodecs, properties={
			'movielangs': relation(self.MovieLang, lazy=False)})
		assign_mapper(self.AChannel, achannels, properties={
			'movielangs': relation(self.MovieLang, lazy=False)})
		assign_mapper(self.SubFormat, subformats, properties={
			'movielangs': relation(self.MovieLang, lazy=False)})
		assign_mapper(self.Lang, languages, properties={
			'movielangs': relation(self.MovieLang, lazy=False)})
		assign_mapper(self.MovieTag, movie_tag)
		assign_mapper(self.Tag, tags, properties={'movietags': relation(self.MovieTag, backref='tag')})
		assign_mapper(self.Loan, loans, properties = {
			'volume'    : relation(self.Volume),
			'collection': relation(self.Collection)})
		assign_mapper(self.Movie, movies, order_by=movies.c.number , properties = {
			'loans'     : relation(self.Loan, backref='movie', cascade='all, delete-orphan'),
			#'tags'       : relation(self.Tag, cascade='all, delete-orphan', secondary=movie_tag,
			'tags'      : relation(self.Tag, secondary=movie_tag,
					primaryjoin=movies.c.movie_id==movie_tag.c.movie_id,
					secondaryjoin=movie_tag.c.tag_id==tags.c.tag_id),
			'languages' : relation(self.MovieLang, cascade='all, delete-orphan')})#}}}
		
		# check if database needs upgrade
		try:
			v = self.Configuration.get_by(param='version')	# returns None if table exists && param ISNULL
		except exceptions.SQLError, e:	# table doesn't exist
			debug.show("DB version: %s" % e)
			v = 0

		if v is not None and v > 1:
			v = int(v.value)
		if v < self.version:
			from dbupgrade import upgrade_database
			if not upgrade_database(self, v):
				raise Exception("cannot upgrade database")
		elif v > self.version:
			debug.show("database version mismatch (detacted:%s; current:%s)" % (v, self.version))
			gutils.warning(self, _('This database requires newer version of Griffith.'))
			raise Exception("database version mismatch")

# for debugging (run: ipython sql.py)
if __name__ == '__main__':
	import sys
	import config, gdebug
	from initialize import locations, location_posters
	from gconsole import check_args, check_args_with_db
	
	class Tmp:
		def __init__(self):
			self.debug = gdebug.GriffithDebug(True)
	tmp = Tmp()
	check_args(tmp)
	locations(tmp)
	tmp.config = config.Config(os.path.join(tmp.locations['home'], 'griffith.cfg'))
	location_posters(tmp.locations, tmp.config)
	
	db = GriffithSQL(tmp.config, tmp.debug, tmp.locations['home'])
	check_args_with_db(tmp)
	
	print '\nGriffithSQL test drive\n======================'
	print "Engine: %s" % (db.metadata.engine.name)
	print 'Database object name: db\n'

# vim: fdm=marker



# -*- coding: UTF-8 -*-

__revision__ = '$Id$'

# Copyright (c) 2007
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils
import movie
import string
import re

plugin_name = "Filmtipset.se"
plugin_description = "Filmtipset.se"
plugin_url = "www.filmtipset.se"
plugin_language = _("Swedish")
plugin_author = "Michael Jahn"
plugin_author_email = "<mikej06@hotmail.com>"
plugin_version = "1.1"

class Plugin(movie.Movie):

	def __init__(self, id):
		self.encode='iso-8859-1'
		self.movie_id = id
		self.url = 'http://www.filmtipset.se/film/' + str(self.movie_id)

	def get_image(self):
		self.image_url = ''
		tmp = gutils.trim(self.page, 'src="http://images.filmtipset.se/posters/', '"')
		if tmp != '':
			self.image_url = 'http://images.filmtipset.se/posters/' + tmp

	def get_o_title(self):
		self.o_title = gutils.trim(self.page, 'Originaltitel:', '</tr>')
		if self.o_title == '':
			self.o_title = gutils.trim(self.page, '<h1>', '</h1>')

	def get_title(self):
		self.title = gutils.trim(self.page, '<h1>', '</h1>')

	def get_director(self):
		self.director = gutils.trim(self.page, 'Regiss&ouml;r:', '</tr>')

	def get_plot(self):
		self.plot = self.regextrim(self.page, '<h2>Om [^>]*[>]', '</tr>')

	def get_year(self):
		self.year = gutils.trim(self.page, 'Utgivnings&aring;r:', '</tr>')

	def get_runtime(self):
		self.runtime = string.strip(gutils.trim(self.page, 'L&auml;ngd:', ' min'))

	def get_genre(self):
		self.genre = string.strip(gutils.trim(self.page, 'Nyckelord:', '</tr>'))
		if self.genre == '':
			self.genre = string.strip(gutils.trim(self.page, 'Genre:', '</tr>'))

	def get_cast(self):
		self.cast = self.regextrim(self.page, 'Sk&aring;despelare [^:]*[:]', '</tr>')
		self.cast = string.replace(self.cast, ', ', '\n')

	def get_classification(self):
		self.classification = ''

	def get_studio(self):
		self.studio = ''

	def get_o_site(self):
		self.o_site = ''
		tmp = gutils.trim(self.page, 'http://www.imdb.com', '"')
		if tmp != '':
			self.o_site = 'http://www.imdb.com' + tmp

	def get_site(self):
		self.site = self.url

	def get_trailer(self):
		self.trailer = ""

	def get_country(self):
		self.country = string.strip(gutils.trim(self.page, 'Produktionsland:', '</span>'))

	def get_rating(self):
		self.rating = "0"

	def get_notes(self):
		self.notes = ''
		tmp = gutils.trim(self.page, 'Alt. titel:', '</span>')
		if tmp != '':
			self.notes = self.notes + 'Alt. titel:' + string.strip(gutils.strip_tags(tmp))

	def regextrim(self,text,key1,key2):
		obj = re.search(key1, text)
		if obj is None:
			return ''
		else:
			p1 = obj.end()
		obj = re.search(key2, text[p1:])
		if obj is None:
			return ''
		else:
			p2 = p1 + obj.start()
		return text[p1:p2]

class SearchPlugin(movie.SearchMovie):

	def __init__(self):
		self.original_url_search   = "http://www.filmtipset.se/search.cgi?field=name&field=orgname&show_graded=1&search_value="
		self.translated_url_search = "http://www.filmtipset.se/search.cgi?field=name&field=orgname&show_graded=1&search_value="
		self.encode='iso-8859-1'

	def search(self,parent_window):
		self.open_search(parent_window)
		tmp_page = gutils.trim(self.page, 'Matchning', 'Hittade')
		if tmp_page == '':
			tmp_page = gutils.trim(self.page, 'Matchning', 'Visa fler')
		self.page = tmp_page
		return self.page

	def get_searches(self):
		elements1 = re.split('href="film/', self.page)
		elements1[0] = None
		for element in elements1:
			if element <> None:
				searchResult = re.search('["&?]', element)
				if searchResult is None:
					self.ids.append(gutils.before(element, '"'))
				else:
					self.ids.append(element[:searchResult.end() - 1])
				self.titles.append(
					gutils.strip_tags(gutils.trim(element, '>', '</a>')) + ' / ' +
					string.replace(gutils.trim(element, 'title="', '"'), '&nbsp;', ' ')
				)



# -*- coding: UTF-8 -*-

__revision__ = '$Id: PluginMovieKinoDe.py 1042 2008-11-15 21:59:58Z mikej06 $'

# Copyright (c) 2006-2007
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils
import movie
import string
import re

plugin_name = "Kino.de"
plugin_description = "KINO.DE"
plugin_url = "www.kino.de"
plugin_language = _("German")
plugin_author = "Michael Jahn"
plugin_author_email = "<mikej06@hotmail.com>"
plugin_version = "1.12"

class Plugin(movie.Movie):
	url_to_use = "http://www.kino.de/kinofilm/"
	url_type = "K"

	def __init__(self, id):
		self.encode='iso-8859-1'
		elements = string.split(id, "_")
		self.movie_id = elements[1]
		if (elements[0] == "V"):
			self.url_to_use = "http://www.kino.de/videofilm/"
			self.url_type = "V"
		else:
			self.url_to_use = "http://www.kino.de/kinofilm/"
			self.url_type = "K"
		self.url = self.url_to_use + str(self.movie_id)

	def initialize(self):
		self.tmp_page = gutils.before(self.page, 'kinode_navi1')
		self.url = self.url_to_use + string.replace(str(self.movie_id), '/', '/credits/')
		self.open_page(self.parent_window)
		self.tmp_creditspage = gutils.before(self.page, 'kinode_navi1')
		self.url = self.url_to_use + string.replace(str(self.movie_id), "/", "/features/")
		self.open_page(self.parent_window)
		self.tmp_dvdfeaturespage = gutils.before(self.page, 'kinode_navi1')

	def get_image(self):
		self.image_url = ''
		tmpdata = self.regextrim(self.tmp_page, '(PRINT[-]CONTENT[-]START|<td class="content">)', '(Dieser Film wurde |>FOTOSHOW<|>KRITIK<)')
		tmpdatasplit = re.split('src="http://.+/flbilder', tmpdata)
		if len(tmpdatasplit) > 2:
			tmpdata = gutils.before(tmpdatasplit[2], '.jpg')
			if tmpdata <> '':
				self.image_url = 'http://images.kino.de/flbilder' + tmpdata + '.jpg'
		elif len(tmpdatasplit) > 1:
			tmpdata = gutils.before(tmpdatasplit[1], '.jpg')
			if tmpdata <> '':
				self.image_url = 'http://images.kino.de/flbilder' + tmpdata + '.jpg'

	def get_o_title(self):
		self.o_title = gutils.trim(self.tmp_page, 'span class="standardsmall">(', ')<')
		if self.o_title == '':
			if self.url_type == 'V':
				self.o_title = gutils.after(self.regextrim(self.tmp_page, 'headline2"[^>]*>[ \t\r\n]*<a href="/videofilm', '</a>'), '>')
			else:
				self.o_title = gutils.after(self.regextrim(self.tmp_page, 'headline2"[^>]*>[ \t\r\n]*<a href="/kinofilm', '</a>'), '>')

	def get_title(self):
		if self.url_type == "V":
			self.title = gutils.after(self.regextrim(self.tmp_page, 'headline2"[^>]*>[ \t\r\n]*<a href="/videofilm', '</a>'), '>')
		else:
			self.title = gutils.after(self.regextrim(self.tmp_page, 'headline2"[^>]*>[ \t\r\n]*<a href="/kinofilm', '</a>'), '>')

	def get_director(self):
		self.director = self.regextrim(self.tmp_creditspage, '>[ ]*Regie', '</a>')
		self.director = gutils.after(self.director, '/star/')
		self.director = gutils.after(self.director, '>')

	def get_plot(self):
		# little steps to perfect plot (I hope ... it's a terrible structured content ... )
		self.plot = gutils.before(self.tmp_page, '<!-- PRINT-CONTENT-ENDE-->')
		self.plot = self.regextrim(self.plot, 'Kurzinfo', '</td></tr>[ \t\r\n]*<tr><td></td></tr>')
		if self.plot != '':
			lastpos = self.plot.rfind('</table>')
			if lastpos == -1:
				self.plot = ''
			else:
				self.plot = self.plot[lastpos:]
		else:
			self.plot = gutils.trim(self.tmp_page, '<span style="line-height:', '</spa')
			if self.plot == '':
				self.plot = gutils.trim(self.tmp_page,"Kurzinfo", "</td></tr><tr><td></td>")
				if (self.plot == ''):
					self.plot = gutils.trim(self.tmp_page,"Kurzinfo", '<script ')
					self.plot = gutils.after(self.plot, '>')
				while len(self.plot) and string.find(self.plot, '</A>') > -1:
					self.plot = gutils.after(self.plot, '</A>');
				self.plot = gutils.after(gutils.after(self.plot, '</table>'), '>')
			else:
				self.plot = gutils.after(self.plot, '>')

	def get_year(self):
		self.year = ''
		tmp = self.regextrim(self.tmp_page, 'span class="standardsmall"[^>]*><strong>', '</span>')
		if tmp <> None:
			srchresult = re.search('[0-9][0-9][0-9][0-9]</strong>', tmp)
			if srchresult <> None:
				self.year = srchresult.string[srchresult.start():srchresult.end()]

	def get_runtime(self):
		self.runtime = ''
		srchresult = re.search('>[0-9]+[ \t]Min[.]<', self.tmp_page)
		if srchresult <> None:
			self.runtime = self.regextrim(srchresult.string[srchresult.start():srchresult.end()], '>', '[^0-9]')

	def get_genre(self):
		self.genre = self.regextrim(self.tmp_page,'span class="standardsmall"[^>]*>[ \t\r\n]*<strong>((DVD|VHS|Laser Disc|Video CD|Blue-ray Disc)</strong>[ \t]-[ \t]<strong>)*', '</strong>[ \t]-[ \t]<strong>')

	def get_cast(self):
		self.cast = gutils.trim(self.tmp_creditspage,'>Cast<', '</table><br')
		if len(self.cast):
			if self.cast.find('>mehr<') > 0:
				self.cast = gutils.after(self.cast, '>mehr<')
			self.cast = gutils.after(self.cast, '>')
			self.cast = re.sub('<tr[ ]+class="(dbtrefferlight|dbtrefferdark)">', "\n", self.cast)
			self.cast = self.cast.replace('&nbsp;', '--flip--')
			self.cast = gutils.clean(self.cast)
			self.cast = re.sub("[\t]+", '', self.cast)
			self.cast = re.sub("[\n]+", "\n", self.cast)
			self.cast = re.sub("--flip--[\n]+", '--flip--', self.cast)
			elements = self.cast.split("\n")
			self.cast = ''
			for element in elements:
				elements2 = element.split('--flip--')
				if len(elements2) > 1:
					if elements2[0] <> '':
						self.cast += elements2[1] + '--flip--' + elements2[0] + "\n"
					else:
						self.cast += elements2[1] + "\n"
				else:
					self.cast += element + "\n"
			self.cast = string.replace(self.cast, '--flip--', _(' as ').encode('utf8'))

	def get_classification(self):
		self.classification = self.regextrim(self.tmp_page,'FSK:( |&nbsp;)+', '</strong>')

	def get_studio(self):
		self.studio = self.regextrim(self.tmp_page, '>[ ]*Verleih:( |&nbsp;)+', '( - |&nbsp;-&nbsp;)*</strong>')
		if (self.studio == ""):
			self.studio = self.regextrim(self.tmp_page, '>[ ]*Anbieter:( |&nbsp;)+', '( - |&nbsp;-&nbsp;)*</strong>')

	def get_o_site(self):
		self.o_site = ""

	def get_site(self):
		self.site = self.url_to_use + self.movie_id;

	def get_trailer(self):
		self.trailer = ""

	def get_country(self):
		self.country = self.regextrim(self.tmp_page, 'span class="standardsmall"[^>]*><strong>((DVD|VHS|Laser Disc|Video CD|Blue-ray Disc)</strong>[ \t]-[ \t]<strong>)*', '</span>')
		if self.country <> None:
			self.country = self.regextrim(self.country, '-[ \t]<strong>', '</strong>')
			self.country = re.sub('[0-9]+$', '', self.country)
		else:
			self.country = ''

	def get_rating(self):
		self.rating = "0"

	def get_notes(self):
		self.notes = ""
		tmp_notes = string.replace(gutils.strip_tags(gutils.trim(self.tmp_dvdfeaturespage, "<b>Sprache</b>", "</td></tr>")), "&nbsp;", "")
		if (tmp_notes != ""):
			self.notes = self.notes + "Sprachen:\n" + tmp_notes + "\n\n"
		tmp_notes = string.replace(gutils.strip_tags(gutils.trim(self.tmp_dvdfeaturespage, "<b>Untertitel</b>", "</td></tr>")), "&nbsp;", "")
		if (tmp_notes != ""):
			self.notes = self.notes + "Untertitel:\n" + tmp_notes + "\n\n"
		tmp_notes = string.replace(gutils.strip_tags(gutils.trim(self.tmp_dvdfeaturespage, "<b>Mehrkanalton</b>", "</td></tr>")), "&nbsp;", "")
		if (tmp_notes != ""):
			self.notes = self.notes + "Mehrkanalton:\n" + tmp_notes + "\n\n"
		tmp_notes = string.replace(gutils.strip_tags(gutils.trim(self.tmp_dvdfeaturespage, "<b>EAN</b>", "</td></tr>")), "&nbsp;", "")
		if (tmp_notes != ""):
			self.notes = self.notes + "EAN:\n" + tmp_notes + "\n\n"
			
	def regextrim(self,text,key1,key2):
		obj = re.search(key1, text)
		if obj is None:
			return ''
		else:
			p1 = obj.end()
		obj = re.search(key2, text[p1:])
		if obj is None:
			return ''
		else:
			p2 = p1 + obj.start()
		return text[p1:p2]

#
# kino.de use iso-8859-1
# it's not necessary to decode the page
# in fact if utf-8 is used you can't search for movies with german umlaut
# and if you use the decode call you get a terrible formatted result list
#

class SearchPlugin(movie.SearchMovie):

	def __init__(self):
		self.original_url_search   = 'http://www.kino.de/search.php?mode=megaSearch&searchCategory=film&inputSearch='
		self.translated_url_search = 'http://www.kino.de/search.php?mode=megaSearch&searchCategory=film&inputSearch='
#		self.encode='utf-8'
		self.encode='iso-8859-1'

	def search(self,parent_window):
		self.open_search(parent_window)
		tmp_pagemovie = self.page
		#
		# try to get all result pages (not so nice, but it works)
		#
		tmp_pagecount = gutils.trim(tmp_pagemovie, '>von', '</a>')
		try:
			tmp_pagecountint = int(tmp_pagecount)
		except:
			tmp_pagecountint = 1
		tmp_pagecountintcurrent = 1
		while (tmp_pagecountint > tmp_pagecountintcurrent and tmp_pagecountintcurrent < 5):
			tmp_pagecountintcurrent = tmp_pagecountintcurrent + 1
			self.url = 'http://www.kino.de/search.php?mode=megaSearch&searchCategory=film&page=' + str(tmp_pagecountintcurrent) + "&inputSearch="
			self.open_search(parent_window)
			tmp_pagemovie = tmp_pagemovie + self.page
		#
		# Look for DVD and VHS
		#
		self.url = "http://www.kino.de/search.php?mode=megaSearch&searchCategory=video&inputSearch="
		self.open_search(parent_window)
		tmp_pagevideo = tmp_pagemovie + self.page
		#
		# try to get all result pages (not so nice, but it works)
		#
		tmp_pagecount = gutils.trim(self.page, '>von', '</a>')
		try:
			tmp_pagecountint = int(tmp_pagecount)
		except:
			tmp_pagecountint = 1
		tmp_pagecountintcurrent = 1
		while (tmp_pagecountint > tmp_pagecountintcurrent and tmp_pagecountintcurrent < 5):
			tmp_pagecountintcurrent = tmp_pagecountintcurrent + 1
			self.url = "http://www.kino.de/search.php?mode=megaSearch&searchCategory=video&page=" + str(tmp_pagecountintcurrent) + "&inputSearch="
			self.open_search(parent_window)
			tmp_pagevideo = tmp_pagevideo + self.page

		self.page = tmp_pagevideo
		return self.page

	def get_searches(self):
		elements1 = re.split('headline3"[^>]*>[ \t\r\n]*<a href="(http://www.kino.de)*/kinofilm/', self.page)
		elements1[0] = None
		for element in elements1:
			if element <> None:
				self.ids.append("K_" + re.sub('[?].*', '', gutils.before(element,'"')))
				self.titles.append('Kino: ' + string.replace(string.replace(
					gutils.strip_tags(
						gutils.trim(element,'>','</a>') + ' (' +
						string.replace(
							gutils.trim(element, '<span class="standardsmall">', "</span>"),
							'<br />', ' - ')
						+ ')'
					),
					'( - (', '('), '))', ')')
				)

		elements2 = re.split('headline3"[^>]*>[ \t\r\n]*<a href="(http://www.kino.de)*/videofilm/', self.page)
		elements2[0] = None
		for element in elements2:
			if element <> None:
				self.ids.append("V_" + re.sub('[?].*', '', gutils.before(element,'"')))
				self.titles.append('Video: ' + string.replace(string.replace(
					gutils.strip_tags(
						gutils.trim(element,'>','</a>') + ' (' +
						string.replace(
							gutils.trim(element, '<span class="standardsmall">', '</span>'),
							'<br />', ' - ')
						+ ')'
					),
					'( - (', '('), '))', ')')
				)

#
# Plugin Test
#
class SearchPluginTest(SearchPlugin):
	#
	# Configuration for automated tests:
	# dict { movie_id -> [ expected result count for original url, expected result count for translated url ] }
	#
	test_configuration = {
		'Rocky Balboa'			: [ 6, 6 ],
		'Arahan'				: [ 6, 6 ],
		'Ein glückliches Jahr'	: [ 3, 3 ]
	}

class PluginTest:
	#
	# Configuration for automated tests:
	# dict { movie_id -> dict { arribute -> value } }
	#
	# value: * True/False if attribute only should be tested for any value
	#        * or the expected value
	#
	test_configuration = {
		'K_rocky-balboa/96132.html' : { 
			'title' 			: 'Rocky Balboa',
			'o_title' 			: 'Rocky Balboa',
			'director'			: 'Sylvester Stallone',
			'plot' 				: True,
			'cast'				: 'Sylvester Stallone' + _(' as ') + 'Rocky Balboa\n\
Antonio Traver' + _(' as ') + 'Mason "The Line" Dixon\n\
Burt Young' + _(' as ') + 'Paulie\n\
Geraldine Hughes' + _(' as ') + 'Marie\n\
Milo Ventimiglia' + _(' as ') + 'Rocky Jr.\n\
James Francis Kelly III' + _(' as ') + 'Steps\n\
Tony Burton' + _(' as ') + 'Duke\n\
A.J. Benza' + _(' as ') + 'L.C.',
			'country'			: 'USA',
			'genre'				: 'Drama',
			'classification'	: 'Freigegeben ab 12 Jahren',
			'studio'			: 'Fox',
			'o_site'			: False,
			'site'				: 'http://www.kino.de/kinofilm/rocky-balboa/96132.html',
			'trailer'			: False,
			'year'				: 2006,
			'notes'				: False,
			'runtime'			: 102,
			'image'				: True,
			'rating'			: False
		},
		'K_ein-glueckliches-jahr/28675.html' : { 
			'title' 			: 'Ein glückliches Jahr',
			'o_title' 			: 'La bonne année',
			'director'			: 'Claude Lelouch',
			'plot' 				: True,
			'cast'				: 'Lino Ventura\n\
Françoise Fabian\n\
Charles Gérard\n\
André Falcon',
			'country'			: 'Frankreich/Italien',
			'genre'				: 'Drama',
			'classification'	: 'Freigegeben ab 12 Jahren',
			'studio'			: 'Columbia TriStar',
			'o_site'			: False,
			'site'				: 'http://www.kino.de/kinofilm/ein-glueckliches-jahr/28675.html',
			'trailer'			: False,
			'year'				: 1973,
			'notes'				: False,
			'runtime'			: 115,
			'image'				: False,
			'rating'			: False
		},
		'V_ein-glueckliches-jahr-dvd/85546.html' : { 
			'title' 			: 'Ein glückliches Jahr',
			'o_title' 			: 'La bonne année',
			'director'			: 'Claude Lelouch',
			'plot' 				: True,
			'cast'				: 'Lino Ventura\n\
Françoise Fabian\n\
Charles Gérard\n\
André Falcon',
			'country'			: 'Frankreich/Italien',
			'genre'				: 'Drama',
			'classification'	: 'Freigegeben ab 12 Jahren',
			'studio'			: 'Black Hill Pictures',
			'o_site'			: False,
			'site'				: 'http://www.kino.de/videofilm/ein-glueckliches-jahr-dvd/85546.html',
			'trailer'			: False,
			'year'				: 1973,
			'notes'				: 'Sprachen:\n\
Deutsch DD 2.0, Französisch DD 2.0\n\
\n\
Mehrkanalton:\n\
Dolby Digital 2.0\n\
\n\
EAN:\n\
7321921998843',
			'runtime'			: 110,
			'image'				: True,
			'rating'			: False
		},
		'V_arahan-vanilla-dvd/90405.html' : { 
			'title' 			: 'Arahan (Vanilla-DVD)',
			'o_title' 			: 'Arahan jangpung dae jakjeon',
			'director'			: 'Ryoo Seung-wan',
			'plot' 				: True,
			'cast'				: 'Ryu Seung-beom' + _(' as ') + 'Sang-hwan\n\
Yoon So-yi' + _(' as ') + 'Wi-jin\n\
Ahn Sung-kee' + _(' as ') + 'Ja-woon\n\
Jung Doo-hong' + _(' as ') + 'Heuk-woon\n\
Yun Ju-sang' + _(' as ') + 'Mu-woon',
			'country'			: 'Südkorea',
			'genre'				: 'Action/Komödie',
			'classification'	: 'Freigegeben ab 16 Jahren',
			'studio'			: 'Splendid',
			'o_site'			: False,
			'site'				: 'http://www.kino.de/videofilm/arahan-vanilla-dvd/90405.html',
			'trailer'			: False,
			'year'				: 2004,
			'notes'				: 'Sprachen:\n\
Deutsch DD 5.1\n\
\n\
Mehrkanalton:\n\
Dolby Digital 5.1\n\
\n\
EAN:\n\
4013549871105',
			'runtime'			: 108,
			'image'				: True,
			'rating'			: False
		}
	}



# __init__.py
# Copyright (C) 2005, 2006, 2007 Michael Bayer mike_mp@zzzcomputing.com
#
# This module is part of SQLAlchemy and is released under
# the MIT License: http://www.opensource.org/licenses/mit-license.php

from sqlalchemy.types import *
from sqlalchemy.sql import *
from sqlalchemy.schema import *
from sqlalchemy.orm import *

from sqlalchemy.engine import create_engine
from sqlalchemy.schema import default_metadata

def __figure_version():
    return '0.3.11'
#    try:
#        from pkg_resources import require
#        import os
#        # NOTE: this only works when the package is either installed,
#        # or has an .egg-info directory present (i.e. wont work with raw SVN checkout)
#        info = require('sqlalchemy')[0]
#        if os.path.dirname(os.path.dirname(__file__)) == info.location:
#            return info.version
#        else:
#            return '(not installed)'
#    except:
#        return '(not installed)'

__version__ = __figure_version()

def global_connect(*args, **kwargs):
    default_metadata.connect(*args, **kwargs)



# -*- coding: UTF-8 -*-

# $Id: PluginMovieMediadis.py 1040 2008-11-15 21:13:49Z mikej06 $

# Copyright (c) 2005-2007 Vasco Nunes
# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils
import movie,string

plugin_name = "Mediadis"
plugin_description = "Entertaining People"
plugin_url = "www.mediadis.com"
plugin_language = _("English")
plugin_author = "Vasco Nunes"
plugin_version = "0.2"

class Plugin(movie.Movie):
	def __init__(self, id):
		self.movie_id = id
		self.url = "http://www.mediadis.com/dvd/detail.asp?id=" + str(self.movie_id)

	def get_image(self):
		self.image_url = gutils.trim(self.page,"<img src=\"http://www.mediadis.com/pictures/big/", ".jpg\" border=\"0\"")
		self.image_url = "http://www.mediadis.com/pictures/big/" + self.image_url + ".jpg"

	def get_o_title(self):
		self.o_title = string.capwords(gutils.trim(self.page,"<b>Original title</b>&nbsp;:&nbsp;","<br>") )

	def get_title(self):
		self.title = self.o_title

	def get_director(self):

		self.director = gutils.trim(self.page,"<b>Director(s)</b>&nbsp;:&nbsp;","<br>")
		self.director = string.replace(self.director, "&nbsp;-&nbsp;", ", ")
		self.director = gutils.strip_tags(self.director)

	def get_plot(self):
		self.plot = gutils.trim(self.page,"<td valign=\"top\" align=\"left\">","</td>")
		self.plot = string.strip(self.plot.decode('latin-1'))
		self.plot = string.replace(self.plot,"<br>", " ")
		self.plot = string.replace(self.plot,"<p>", " ")
		self.plot = string.replace(self.plot,"'","_")
		self.plot = string.strip(gutils.strip_tags(self.plot))

	def get_year(self):
		self.year = gutils.trim(self.page,"<b>Year</b>&nbsp;:&nbsp;","<br>")

	def get_runtime(self):
		self.runtime = gutils.trim(self.page,"<b>Duration</b>&nbsp;:&nbsp;","&nbsp;min")

	def get_genre(self):
		self.genre = gutils.trim(self.page,"<b>Genres</b>&nbsp;:&nbsp;","<br>")
		self.genre = string.replace(self.genre,"&nbsp;-&nbsp;",", ")

	def get_cast(self):
		self.cast = ""
		self.cast = gutils.trim(self.page,"<b>Actors</b>&nbsp;:&nbsp;","<br>")
		self.cast = string.replace(self.cast,"&nbsp;-&nbsp;", "\n")
		self.cast = string.strip(gutils.strip_tags(self.cast))

	def get_classification(self):
		self.classification = ""

	def get_studio(self):
		self.studio = gutils.trim(self.page,"<b>Studio</b>&nbsp;:&nbsp;","<br>")

	def get_o_site(self):
		self.o_site = ""

	def get_site(self):
		self.site = ""

	def get_trailer(self):
		self.trailer = ""

	def get_country(self):
		self.country = gutils.trim(self.page,"<b>Country</b>&nbsp;:&nbsp;","<br>")

	def get_rating(self):
		self.rating = gutils.trim(self.page, "Global rating :&nbsp;<b>","/10</b>&nbsp;")
		if self.rating:
			self.rating = string.replace(self.rating, ",", ".")
		self.rating = str(float(gutils.clean(self.rating)))

class SearchPlugin(movie.SearchMovie):

	def __init__(self):
		self.original_url_search	= "http://www.mediadis.com/dvd/search.asp?t=1&kw=";
		self.translated_url_search	= "http://www.mediadis.com/dvd/search.asp?t=1&kw=";

	def search(self,parent_window):
		self.open_search(parent_window)
		self.sub_search()
		return self.page

	def sub_search(self):
		self.page = gutils.trim(self.page,"Click to sort out", "Result of your research on the criteria")

	def get_searches(self):
		elements = string.split(self.page,"<td rowspan=\"4\" align=\"center\" valign=\"top\" style=\"padding:4px;\">")
		self.number_results = elements[-1]

		if (elements[0]<>''):
			for element in elements:
				self.ids.append(gutils.trim(element,"/dvd/detail.asp?id=","\">"))
				self.titles.append(gutils.convert_entities(gutils.trim(element,"\" class=\"dvd-search-title\">","</a>")))	
		else:
			self.number_results = 0



# -*- coding: UTF-8 -*-

__revision__ = '$Id: edit.py 1040 2008-11-15 21:13:49Z mikej06 $'

# Copyright (c) 2005-2008 Vasco Nunes, Piotr Ożarowski

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils
import os
import update
import gtk
import amazon
from urllib import urlcleanup
import tempfile
import movie
import delete
from PIL import Image

def change_poster(self):
	"""
	changes movie poster image to a custom one
	showing a file chooser dialog to select it
	"""
	picture = self.widgets['movie']['picture']
	number = self.get_maintree_selection()[0]
	if number is None:
		gutils.error(self,_("You have no movies in your database"), self.widgets['window'])
		return False
	filename = gutils.file_chooser(_("Select image"), action=gtk.FILE_CHOOSER_ACTION_OPEN, buttons=(gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,gtk.STOCK_OPEN,gtk.RESPONSE_OK), name="", folder=self.locations['desktop'], picture=True)
	if filename and filename[0]:
		filename = filename[0].decode('UTF-8')
		update_image(self, number, filename)

def update_image(self, number, file_path):
	import shutil
	try:
		self.widgets['movie']['picture'].set_from_pixbuf(\
				gtk.gdk.pixbuf_new_from_file(file_path).scale_simple(100, 140, gtk.gdk.INTERP_BILINEAR))
	except Exception, e:
		self.debug.show(str(e))
		gutils.error(self, _("Image not valid."), self.widgets['window'])
		return False

	filename = os.path.basename(file_path)
	new_image = os.path.splitext(filename)[0]
	if self.db.Movie.get_by(image=new_image) is not None:
		i = 0
		while True:
			i += 1
			if self.db.Movie.get_by(image="%s_%s" % (new_image, i)) is None:
				new_image = "%s_%s" % (new_image, i)
				break

	movie = self.db.Movie.get_by(number=number)
	old_image = os.path.join(self.locations['posters'], "%s.jpg" % movie.image)
	delete.delete_poster(self, old_image)
	movie.image = new_image
	movie.update()
	movie.flush()

	shutil.copyfile(file_path, os.path.join(self.locations['posters'], "%s.jpg" % new_image))

	gutils.make_thumbnail(self, '%s.jpg' % new_image)
	gutils.make_medium_image(self, '%s.jpg' % new_image)
	update_tree_thumbnail(self, os.path.join(self.locations['posters'], 't_%s.jpg' % new_image))

	self.widgets['movie']['picture_button'].set_sensitive(True)
	self.widgets['add']['delete_poster'].set_sensitive(True)
	self.widgets['menu']['delete_poster'].set_sensitive(True)

	self.update_statusbar(_("Image has been updated"))

def delete_poster(self):
	movie = self.db.Movie.get_by(movie_id=self._movie_id)
	if not movie:
		self.debug.show("Can't delete unknown movie's poster!")
		return False
	response = gutils.question(self, _("Are you sure you want to delete this poster?"), 1, self.widgets['window'])
	if response==-8:
		image_path = os.path.join(self.locations['images'], 'default.png')
		handler = self.widgets['movie']['picture'].set_from_pixbuf(gtk.gdk.pixbuf_new_from_file(image_path))
		gutils.garbage(handler)
		update_tree_thumbnail(self, os.path.join(self.locations['images'], 'default_thumbnail.png'))
		# update in database
		old_image = movie.image
		movie.image = None
		movie.update()
		movie.flush()
		self.update_statusbar(_("Image has been updated"))

		self.widgets['add']['delete_poster'].set_sensitive(False)
		self.widgets['menu']['delete_poster'].set_sensitive(False)
		self.widgets['movie']['picture_button'].set_sensitive(False)
		if old_image:
			delete.delete_poster(self, old_image)
	else:
		pass

def update_tree_thumbnail(self, t_image_path):
	treeselection = self.widgets['treeview'].get_selection()
	(tmp_model, tmp_iter) = treeselection.get_selected()
	self.Image.set_from_file(t_image_path)
	pixbuf = self.Image.get_pixbuf()
	self.treemodel.set_value(tmp_iter, 1, pixbuf)

def fetch_bigger_poster(self):
	match = 0
	self.debug.show("fetching poster from amazon")
	movie = self.db.Movie.get_by(movie_id=self._movie_id)
	if movie is None:
		gutils.error(self,_("You have no movies in your database"), self.widgets['window'])
		return False
	current_poster = movie.image
	amazon.setLicense("04GDDMMXX8X9CJ1B22G2")

	locale = self.config.get('amazon_locale', 0, section='add')
	keyword = self.widgets['movie']['o_title'].get_text().decode('utf-8')
	if locale == '1':
		locale = 'uk'
	elif locale == '2':
		locale = 'de'
		keyword = self.widgets['movie']['title'].get_text().decode('utf-8')
	elif locale == '3':
		locale = 'ca'
	elif locale == '4':
		locale = 'fr'
	elif locale == '5':
		locale = 'jp'
	else:
		locale = None

	try:
		result = amazon.searchByKeyword(keyword, type="Large", product_line="DVD", locale=locale)
		self.debug.show("Posters found on amazon: %s posters" % result.TotalResults)
	except:
		gutils.warning(self, _("No posters found for this movie."))
		return

	from widgets import connect_poster_signals, reconnect_add_signals
	connect_poster_signals(self, get_poster_select_dc, result, current_poster)

	if not len(result.Item):
		gutils.warning(self, _("No posters found for this movie."))
		reconnect_add_signals(self)
		return

	for f in range(len(result.Item)):
		if self.widgets['movie']['o_title'].get_text().decode('utf-8') == result.Item[f].ItemAttributes.Title:
			get_poster(self, f, result, current_poster)
			return

	self.treemodel_results.clear()
	self.widgets['add']['b_get_from_web'].set_sensitive(False) # disable movie plugins (result window is shared)

	for f in range(len(result.Item)):
		if hasattr(result.Item[f], "LargeImage") and len(result.Item[f].LargeImage.URL):
			title = result.Item[f].ItemAttributes.Title
			myiter = self.treemodel_results.insert_before(None, None)
			self.treemodel_results.set_value(myiter, 0, str(f))
			self.treemodel_results.set_value(myiter, 1, title)

	self.widgets['results']['window'].show()
	self.widgets['results']['window'].set_keep_above(True)

def get_poster_select_dc(self, event, mself, result, current_poster):
	if event.type == gtk.gdk._2BUTTON_PRESS:
		get_poster(mself, None, result, current_poster)

def get_poster_select(self, mself, result, current_poster):
	get_poster(mself, None, result, current_poster)

def get_poster(self, f, result, current_poster):
	from widgets import reconnect_add_signals
	if f is None:
		treeselection = self.widgets['results']['treeview'].get_selection()
		(tmp_model, tmp_iter) = treeselection.get_selected()
		if tmp_iter is None:
			return False
		f = int(tmp_model.get_value(tmp_iter, 0))
		self.widgets['results']['window'].hide()

	file_to_copy = tempfile.mktemp(suffix=self.widgets['movie']['number'].get_text().decode('utf-8'), \
		dir=self.locations['temp'])
	file_to_copy += ".jpg"
	if len(result.Item[f].LargeImage.URL):
		try:
			progress = movie.Progress(self.widgets['window'],_("Fetching poster"),_("Wait a moment"))
			retriever = movie.Retriever(result.Item[f].LargeImage.URL, self.widgets['window'], progress, file_to_copy)
			retriever.start()
			while retriever.isAlive():
				progress.pulse()
				if progress.status:
					retriever.suspend()
				while gtk.events_pending():
					gtk.main_iteration()
			progress.close()
			urlcleanup()
		except:
			gutils.warning(self, _("Sorry. A connection error has occurred."))

	if  os.path.isfile(file_to_copy):
		try:
			im = Image.open(file_to_copy)
		except IOError:
			self.debug.show("failed to identify %s"%file_to_copy)

		if im.size == (1,1):
			from urllib import FancyURLopener, urlretrieve
			url = FancyURLopener().open("http://www.amazon.com/gp/product/images/%s" % result.Item[f].ASIN).read()
			if url.find('no-img-sm._V47056216_.gif') > 0:
				self.debug.show('No image available')
				gutils.warning(self, _("Sorry. This movie is listed but has no poster available at Amazon.com."))
				return False
			url = gutils.after(url, 'id="imageViewerDiv"><img src="')
			url = gutils.before(url, '" id="prodImage"')
			urlretrieve(url, file_to_copy)
			try:
				im = Image.open(file_to_copy)
			except IOError:
				self.debug.show("failed to identify %s"%file_to_copy)

		if im.mode != 'RGB': # convert GIFs
			im = im.convert('RGB')
			im.save(file_to_copy, 'JPEG')
		
		handler = self.widgets['big_poster'].set_from_file(file_to_copy)

		self.widgets['poster_window'].show()
		self.widgets['poster_window'].move(0,0)
		response = gutils.question(self, \
				_("Do you want to use this poster instead?"), \
				1, self.widgets['window'])
		if response == -8:
			self.debug.show("Using fetched poster, updating and removing old one from disk.")
			update_image(self, self.widgets['movie']['number'].get_text().decode('utf-8'), file_to_copy)
		else:
			self.debug.show("Reverting to previous poster and deleting new one from disk.")
			try:
				os.remove(file_to_copy)
			except:
				self.debug.show("no permission for %s"%file_to_copy)

		self.widgets['poster_window'].hide()
	else:
		gutils.warning(self, _("Sorry. This movie is listed but has no poster available at Amazon.com."))
	reconnect_add_signals(self)




# -*- coding: iso-8859-15 -*-

__revision__ = '$Id: PluginMovieIMDB-es.py 389 2006-07-29 18:43:35Z piotrek $'

# Copyright (c) 2006 Pedro D. Sánchez
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils
import movie
import string

plugin_name		= 'IMDb-es'
plugin_description	= 'Internet Movie Database Spanish'
plugin_url		= 'spanish.imdb.com'
plugin_language		= _('Spanish')
plugin_author		= 'Pedro D. Sánchez'
plugin_author_email	= '<pedrodav@gmail.com>'
plugin_version		= '0.2'

class Plugin(movie.Movie):
	def __init__(self, id):
		self.encode='iso-8859-15'
		self.movie_id = id
		self.url = "http://spanish.imdb.com/title/tt%s" % str(self.movie_id)

	def get_image(self):
		tmp = string.find(self.page, 'a name="poster"')
		if tmp == -1:		# poster not available
			self.image_url = ''
		else:
			self.image_url = gutils.trim(self.page[tmp:], 'src="', '"')

	def get_o_title(self):
		self.o_title = gutils.trim(self.page, '<strong class="title">', ' <small>')

	def get_title(self):
		tmp = 0
		tmpTot = 0
		while (tmp <> -1):
			auxTitle = ''
			tmp = string.find(self.page[tmpTot:], '<i class="transl">')
			if tmp <> -1:
				auxTitle = gutils.trim(self.page[tmpTot:], '<i class="transl">', '</i>')
				if string.find(auxTitle, '(Spain)') <> -1:
					auxTitle = string.replace(auxTitle, '&#32;', ' ')
					auxTitle = string.replace(auxTitle, ' (Argentina) ', '')
					auxTitle = string.replace(auxTitle, ' (Spain) ', '')
					auxTitle = string.replace(auxTitle, ' (Mexico) ', '')
					auxTitle = string.replace(auxTitle, '  [es]', '')
					tmp = -1
				tmpTot = tmpTot + tmp + 1
		if auxTitle <> '':
			self.title = auxTitle
		else:
			self.title = self.o_title

	def get_director(self):
		self.director = gutils.trim(self.page,'Dirigida por</b><br>', '<br>')

	def get_plot(self):
		self.plot = gutils.trim(self.page, '<b class="ch">Resumen', '<a href="/rg/title-tease/plot')
		self.plot = gutils.after(self.plot, ':</b> ')

	def get_year(self):
		self.year = gutils.trim(self.page, '<a href="/Sections/Years/', '</a>)</small>')
		self.year = gutils.after(self.year, '">')

	def get_runtime(self):
		self.runtime = gutils.trim(self.page, '<b class="ch">Duración:</b>', ' min')
		if self.runtime == '':
			self.runtime = gutils.trim(self.page, '<b class="ch">Duraci&oacute;n:</b>', ' min')

	def get_genre(self):
		self.genre = gutils.trim(self.page, '<a href="/Sections/Genres/', '<br>')
		self.genre = gutils.after(self.genre, '/">')
		self.genre = string.replace(self.genre, '(más)', '')
		self.genre = string.replace(self.genre, '(m&aacute;s)', '')

	def get_cast(self):
		self.cast = ''
		self.cast = gutils.trim(self.page, 'Cast overview, first billed only:', '<a href="fullcredits">')
		if (self.cast==''):
			self.cast = gutils.trim(self.page, 'cast: ','<a href="fullcredits">')
		self.cast = string.replace(self.cast, ' .... ', _(' as '))
		self.cast = string.replace(self.cast, '</tr><tr>', "\n")
		self.cast = string.replace(self.cast, '</tr><tr bgcolor="#FFFFFF">', "\n")
		self.cast = string.replace(self.cast, '</tr><tr bgcolor="#F0F0F0">', "\n")
		self.cast = string.strip(gutils.strip_tags(self.cast))

	def get_classification(self):
		self.classification = gutils.trim(self.page, '<a href="/List?certificates=Spain:', '</a>')
		self.classification = gutils.after(self.classification, '">Spain:')
		#self.classification = gutils.trim(self.page, 'MPAA</a>:</b> ', '<br>')
		#self.classification = ''

	def get_studio(self):
		self.studio = ''

	def get_o_site(self):
		self.o_site = ''

	def get_site(self):
		self.site = "http://spanish.imdb.com/title/tt%s" % self.movie_id

	def get_trailer(self):
		self.trailer = "http://spanish.imdb.com/title/tt%s/trailers" % self.movie_id

	def get_country(self):
		self.country = gutils.trim(self.page, '<b class="ch">País:</b>', '</a>')
		if self.country == '':
			self.country = gutils.trim(self.page, '<b class="ch">Pa&iacute;s:</b>', '</a>')
		self.country = gutils.after(self.country, '/">')

	def get_rating(self):
		self.rating = gutils.trim(self.page, '<b class="ch">Calificación de los usuarios:</b>', '/10</b> (')
		if self.rating == '':
			self.rating = gutils.trim(self.page, '<b class="ch">Calificaci&oacute;n de los usuarios:</b>', '/10</b> (')
		if self.rating:
			self.rating = str(float(gutils.clean(self.rating)))

class SearchPlugin(movie.SearchMovie):

	def __init__(self):
		self.original_url_search	= 'http://spanish.imdb.com/find?more=tt;q='
		self.translated_url_search	= 'http://spanish.imdb.com/find?more=tt;q='
		self.encode = 'iso-8859-15'

	def search(self,parent_window):
		self.open_search(parent_window)
		self.sub_search()
		return self.page

	def sub_search(self):
		self.page = gutils.trim(self.page, '</b> found the following results:', '<b>Suggestions For Improving Your Results</b>');
		self.page = self.page.decode('iso-8859-15')

	def get_searches(self):
		elements = string.split(self.page, '<li>')

		if (elements[0]<>''):
			for element in elements:
				self.ids.append(gutils.trim(element, '/title/tt','/?fr='))
				self.titles.append(gutils.strip_tags(gutils.convert_entities(gutils.trim(element, ';fm=1">', '</li>'))))



# -*- coding: UTF-8 -*-

__revision__ = '$Id: PluginMovieDVDPalace.py 1040 2008-11-15 21:13:49Z mikej06 $'

# Copyright (c) 2006-2007
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils
import movie
import string
import re

plugin_name = "DVD-Palace"
plugin_description = "DVD-Onlinemagazin mit DVD-Datenbank"
plugin_url = "www.dvd-palace.de"
plugin_language = _("German")
plugin_author = "Michael Jahn"
plugin_author_email = "<mikej06@hotmail.com>"
plugin_version = "1.0"

class Plugin(movie.Movie):

	def __init__(self, id):
		self.encode   = 'iso-8859-1'
		self.movie_id = id
		self.url      = 'http://www.dvd-palace.de/dvd-datenbank/' + self.movie_id

	def get_image(self):
		self.image_url = gutils.trim(self.page, 'src="/showcover.php?', '"')
		if self.image_url <> '':
			self.image_url = 'http://www.dvd-palace.de/showcover.php?' + self.image_url

	def get_o_title(self):
		self.o_title = gutils.trim(self.page, 'Originaltitel', '</b>')
		if self.o_title == '':
			self.o_title = gutils.trim(self.page, '<TITLE>', ' - DVD Details')

	def get_title(self):
		self.title = gutils.trim(self.page, '<TITLE>', ' - DVD Details')

	def get_director(self):
		self.director = gutils.trim(self.page, 'Regisseur(e)', '</TR>')

	def get_plot(self):
		self.plot = re.sub(
			'[0-9 ]+Views', '',
			re.sub(
				'[]', '-',
				re.sub(
					'[\x93]', '"', self.regextrim(self.page, 'showcover.php[^>]*>', '</td>'))))

	def get_year(self):
		self.year = gutils.after(gutils.trim(gutils.trim(self.page, 'Originaltitel', '</TR>'), '(', ')'), ' ')

	def get_runtime(self):
		self.runtime = gutils.strip_tags(string.replace(gutils.trim(self.page, 'Laufzeit', ' min'), 'ca. ', ''))

	def get_genre(self):
		self.genre = string.replace(string.replace(gutils.trim(self.page, 'Genre(s)', '</TR>'), '&nbsp;', ''), '<br>', ', ')

	def get_cast(self):
		self.cast = string.replace(
			re.sub('<em>[^<]*</em>', ' ',
				re.sub(',[ ]*', '\n',
					gutils.trim(self.page, 'Darsteller / Sprecher', '</TR>')
				)
			),
			'\n ', '\n')

	def get_classification(self):
		self.classification = string.replace(gutils.trim(self.page, 'Altersfreigabe (FSK)', '</TR>'), '&nbsp;', '')

	def get_studio(self):
		self.studio = string.replace(string.replace(gutils.trim(self.page, 'Label', '</td>'), '&nbsp;', ''), ':', '')

	def get_o_site(self):
		self.o_site = ""

	def get_site(self):
		self.site = self.url

	def get_trailer(self):
		self.trailer = ''

	def get_country(self):
		self.country = gutils.before(gutils.trim(gutils.trim(self.page, 'Originaltitel', '</TR>'), '(', ')'), ' ')

	def get_rating(self):
		self.rating = "0"

	def get_notes(self):
		self.notes = ""
		tmp_notes = re.sub('^[ \t]+', '',
			gutils.strip_tags(
			re.sub('(<br>|<br />)', '\r\n',
			re.sub('[\r\n]+', '',
			re.sub('[ \t][ \t\r\n]+', ' ',
			gutils.trim(self.page, 'Bildformat(e)', '</TR>')))))
		)
		if (tmp_notes != ""):
			self.notes = self.notes + "Bildformat(e):\n" + tmp_notes + "\n"
		tmp_notes = re.sub('^[ \t]+', '',
			gutils.strip_tags(
			re.sub('(<br>|<br />)', '\r\n',
			re.sub('[\r\n]+', '',
			re.sub('[ \t][ \t\r\n]+', ' ',
			gutils.trim(self.page, 'Tonformat(e)', '</TR>')))))
		)
		if (tmp_notes != ""):
			self.notes = self.notes + "Tonformat(e):\n" + tmp_notes + "\n\n"
		tmp_notes = re.sub('^[ \t]+', '',
			gutils.strip_tags(
			re.sub('(<br>|<br />)', '\r\n',
			re.sub('[\r\n]+', '',
			re.sub('[ \t][ \t\r\n]+', ' ',
			gutils.trim(self.page, 'Untertitel', '</TR>')))))
		)
		if (tmp_notes != ""):
			self.notes = self.notes + "Untertitel:" + tmp_notes + "\n\n"
			
	def regextrim(self,text,key1,key2):
		obj = re.search(key1, text)
		if obj is None:
			return ''
		else:
			p1 = obj.end()
		obj = re.search(key2, text[p1:])
		if obj is None:
			return ''
		else:
			p2 = p1 + obj.end()
		return text[p1:p2]

class SearchPlugin(movie.SearchMovie):

	def __init__(self):
		self.original_url_search   = "http://www.dvd-palace.de/dvddatabase/dbsearch.php?action=1&suchbegriff="
		self.translated_url_search = "http://www.dvd-palace.de/dvddatabase/dbsearch.php?action=1&suchbegriff="
		self.encode='iso-8859-1'

	def search(self,parent_window):
		self.open_search(parent_window)
		tmp_pagemovie = self.page
		#
		# try to get all result pages (not so nice, but it works)
		#
		tmp_pagecount = gutils.trim(tmp_pagemovie, 'Seiten (<b>', '</b>)')
		try:
			tmp_pagecountint = int(tmp_pagecount)
		except:
			tmp_pagecountint = 1
		tmp_pagecountintcurrent = 1
		while (tmp_pagecountint > tmp_pagecountintcurrent and tmp_pagecountintcurrent < 5):
			self.url = "http://www.dvd-palace.de/dvddatabase/dbsearch.php?action=1&start=" + str(tmp_pagecountintcurrent * 20) + "&suchbegriff="
			self.open_search(parent_window)
			tmp_pagemovie = tmp_pagemovie + self.page
			tmp_pagecountintcurrent = tmp_pagecountintcurrent + 1
		self.page = tmp_pagemovie
		return self.page

	def get_searches(self):
		elements1 = re.split('&nbsp;<a title="[^"]+" href="/dvd-datenbank/', self.page)
		elements1[0] = None
		for element in elements1:
			if element <> None:
				self.ids.append(gutils.before(element,'"'))
				self.titles.append(
					gutils.trim(element, '>', '</a>') +
					gutils.strip_tags(
						' (' +
						re.sub('[ \t\n][ \t\n]+', ' ',
						string.replace(
						string.replace(
							self.regextrim(element, '<div [^>]*>', '</div>'),
							'<br>', ' - '),
							'&nbsp;', ''))
						+ ')'
					)
				)
			
	def regextrim(self,text,key1,key2):
		obj = re.search(key1, text)
		if obj is None:
			return ''
		else:
			p1 = obj.end()
		obj = re.search(key2, text[p1:])
		if obj is None:
			return ''
		else:
			p2 = p1 + obj.end()
		return text[p1:p2]



# -*- coding: UTF-8 -*-

__revision__ = '$Id: PluginExportXML.py 1040 2008-11-15 21:13:49Z mikej06 $'

# Copyright (c) 2005-2007 Vasco Nunes, Piotr Ożarowski
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import xml.dom.minidom
import xml.dom.ext
import gtk
import gutils
import os

plugin_name = "XML"
plugin_description = _("Full XML list export plugin")
plugin_author = "Vasco Nunes"
plugin_author_email = "<vasco.m.nunes@gmail.com>"
plugin_version = "0.1"

class ExportPlugin:

	def __init__(self, database, locations, parent_window, debug, **kwargs):
		self.db = database
		self.locations = locations
		self.parent = parent_window
		if kwargs.has_key('config'):
			self.persistent_config = kwargs['config']
		else:
			self.persistent_config = None
		self.export_xml()

	def export_xml(self):
		basedir = None
		if not self.persistent_config is None:
			basedir = self.persistent_config.get('export_dir', None, section='export-xml')
		if basedir is None:
			filename = gutils.file_chooser(_("Export a %s document")%"XML", action=gtk.FILE_CHOOSER_ACTION_SAVE, \
				buttons=(gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,gtk.STOCK_SAVE,gtk.RESPONSE_OK),name='griffith_list.xml')
		else:
			filename = gutils.file_chooser(_("Export a %s document")%"XML", action=gtk.FILE_CHOOSER_ACTION_SAVE, \
				buttons=(gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,gtk.STOCK_SAVE,gtk.RESPONSE_OK),name='griffith_list.xml',folder=basedir)
		if filename[0]:
			if not self.persistent_config is None and filename[1]:
				self.persistent_config.set('export_dir', filename[1], section='export-xml')
				self.persistent_config.save()
			overwrite = None
			if os.path.isfile(filename[0]):
				response = gutils.question(self, _("File exists. Do you want to overwrite it?"), 1, self.parent)
				if response==-8:
					overwrite = True
				else:
					overwrite = False
					
			if overwrite == True or overwrite is None:
				# create document
				impl = xml.dom.minidom.getDOMImplementation()
				doc  = impl.createDocument(None, "root", None)
				root = doc.documentElement
				
				# create object
				for movie in self.db.Movie.select():
					e = doc.createElement('movie')
					root.appendChild(e)
					for key in movie.c.keys():
						e2 = doc.createElement(key)
						if movie[key] is None:
							value = ''
						elif movie[key] in (True, False):
							value = str(int(movie[key]))
						else:
							value = str(movie[key])
						t = doc.createTextNode(value)
						e2.appendChild(t)
						e.appendChild(e2)
					
				# write XML to file
				fp = open(filename[0], "w")
				xml.dom.ext.PrettyPrint(doc, fp)
				fp.close()
				gutils.info(self, _("%s file has been created.")%"XML", self.parent)



# -*- coding: UTF-8 -*-

# $Id: PluginMovieMoviefone.py 1040 2008-11-15 21:13:49Z mikej06 $

# Copyright (c) 2005-2007 Vasco Nunes
# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils
import movie,string

plugin_name = "Moviefone"
plugin_description = "A Service of America Online"
plugin_url = "movies.aol.com"
plugin_language = _("English")
plugin_author = "Vasco Nunes"
plugin_version = "0.3"

class Plugin(movie.Movie):
	def __init__(self, id):
		self.movie_id = id
		self.url = "http://movies.aol.com/movie/main.adp?_pgtyp=pdct&mid=" + str(self.movie_id)

	def get_image(self):
		self.image_url = gutils.trim(self.page,"http://cdn.channel.aol.com/amgvideo/dvd/cov150/",".jpg")
		self.image_url = "http://cdn.channel.aol.com/amgvideo/dvd/cov150/" + self.image_url + ".jpg"

	def get_o_title(self):
		self.o_title = string.capwords(gutils.trim(self.page,"<title>"," - Moviefone</title>") )

	def get_title(self):
		self.title = self.o_title

	def get_director(self):
		self.director = gutils.trim(self.page,"<strong>Directed By:</strong> ","<br />")
		self.director = string.strip(gutils.strip_tags(self.director))

	def get_plot(self):
		self.plot = gutils.trim(self.page,"<strong>Synopsis:</strong> ","<br />")
		self.plot = string.strip(gutils.strip_tags(self.plot))

	def get_year(self):
		self.year = gutils.trim(self.page,"<strong>DVD Release Date:</strong> ","<br />")
		self.year = self.year[-4:]

	def get_runtime(self):
		self.runtime = gutils.trim(self.page,"<strong>Run Time:</strong> "," min.<br />")

	def get_genre(self):
		self.genre = gutils.trim(self.page,"<strong>Genre:</strong> ","<br />")

	def get_cast(self):
		self.cast = gutils.trim(self.page,"<strong>Starring:</strong> ","<br />")
		self.cast = string.strip(gutils.strip_tags(self.cast))

	def get_classification(self):
		self.classification = gutils.trim(self.page,"<strong>Rating:</strong> ","<br />")

	def get_studio(self):
		self.studio = gutils.trim(self.page,"<strong>Released By:</strong> ","<br />")

	def get_o_site(self):
		self.o_site = ""

	def get_site(self):
		self.site = ""

	def get_trailer(self):
		self.trailer = gutils.trim(self.page,"""onclick="setTrailerOmni();window.open('""", \
			"','_dlplayer'")

	def get_country(self):
		self.country = ""

	def get_rating(self):
		self.rating = "0"

class SearchPlugin(movie.SearchMovie):
	def __init__(self):
		self.original_url_search	= "http://movies.aol.com/search/encyresults.adp?query=";
		self.translated_url_search	= "http://movies.aol.com/search/encyresults.adp?query=";

	def search(self,parent_window):
		self.open_search(parent_window)
		self.sub_search()
		return self.page

	def sub_search(self):
		self.page = gutils.trim(self.page,"--start LT_MultiColumn_1.0 module-->", 'pagnationleft">Results   ')

	def get_searches(self):
		elements = string.split(self.page,'class="dvdtitle">')
		elements[0] = ''

		for element in elements:
			element = gutils.trim( element, '<a href="', '<br/>' )
			if element != '':
				self.ids.append( gutils.after( gutils.trim( element, 'movie/','/main') , '/' ) )
				self.titles.append( string.replace( gutils.after( element, '">' ), '</a></span>', '' ) )



# -*- coding: UTF-8 -*-

__revision__ = '$Id: PluginMovieZelluloid.py 1042 2008-11-15 21:59:58Z mikej06 $'

# Copyright (c) 2007 Michael Jahn
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils
import movie
import string
import re

plugin_name         = 'Zelluloid.de'
plugin_description  = 'ZELLULOID.DE'
plugin_url          = 'www.zelluloid.de'
plugin_language     = _('German')
plugin_author       = 'Michael Jahn'
plugin_author_email = '<mikej06@hotmail.com>'
plugin_version      = '1.1'

class Plugin(movie.Movie):
	index_url = 'http://www.zelluloid.de/filme/index.php3?id='
	
	def __init__(self, id):
		self.encode='iso-8859-1'
		self.movie_id = id
		self.url = "http://www.zelluloid.de/filme/details.php3?id=" + self.movie_id

	def initialize(self):
		self.detail_page = self.page
		self.url = self.index_url + self.movie_id
		self.page = self.open_page(url=self.url)

	def get_image(self):
		self.image_url = 'http://www.zelluloid.de/images/poster/' + gutils.trim(self.page, '<IMG SRC="/images/poster/', '"');

	def get_o_title(self):
		self.o_title = gutils.trim(self.page, 'Originaltitel: ', '<BR>')
		if self.o_title == '':
			self.o_title = gutils.trim(self.page, '<title>', '|')

	def get_title(self):
		self.title = gutils.trim(self.page, '<title>', '|')

	def get_director(self):
		self.director = gutils.trim(self.detail_page, 'Regie', '</A>')

	def get_plot(self):
		self.plot = gutils.trim(self.page, '<DIV CLASS=bigtext>', '</DIV>')
		
	def get_year(self):
		self.year = ''
		elements = string.split(self.detail_page, '/directory/az.php3?j')
		elements[0] = ''
		delimiter = ''
		for element in elements:
			if element <> '':
				self.year = self.year + delimiter + gutils.trim(element, '>', '<')
				delimiter = ', '

	def get_runtime(self):
		self.runtime = gutils.trim(self.detail_page, 'ca.&nbsp;', '&nbsp;min');

	def get_genre(self):
		self.genre = ''
		elements = string.split(self.detail_page, '/directory/az.php3?g')
		elements[0] = ''
		delimiter = ''
		for element in elements:
			if element <> '':
				self.genre = self.genre + delimiter + gutils.trim(element, '>', '<')
				delimiter = ', '

	def get_cast(self):
		self.cast = gutils.trim(self.detail_page, 'alt="Besetzung"', '<TD COLSPAN=')
		self.cast = self.cast.replace('<A HREF=', '--flip--' + '<A HREF=')
		self.cast = gutils.strip_tags(self.cast)
		self.cast = gutils.after(self.cast, '>')
		elements = self.cast.split('\n')
		self.cast = ''
		for element in elements:
			elements2 = element.split("--flip--")
			if len(elements2) > 1:
				self.cast += elements2[1] + '--flip--' + elements2[0] + '\n'
			else:
				self.cast += element + '\n'
		self.cast = string.replace(self.cast, '--flip--', _(' as ').encode('utf8'))

	def get_classification(self):
		self.classification = gutils.trim(self.detail_page, 'FSK: ', '</TD>')
		self.classification = re.sub('[,<].*', '', self.classification)

	def get_studio(self):
		self.studio = gutils.strip_tags(gutils.trim(self.detail_page, 'alt="Produktion"', '&nbsp;'))
		if self.studio == '':
			self.studio = gutils.trim(self.detail_page, 'alt="Produktion"', '</TABLE>')
		self.studio = gutils.after(self.studio, '>')
		self.studio = self.studio.replace('\n', ', ')
		self.studio = re.sub('((^, )|(, $))', '', self.studio)
		
	def get_o_site(self):
		self.o_site = ""

	def get_site(self):
		self.site = "http://www.zelluloid.de/filme/details.php3?id=" + self.movie_id

	def get_trailer(self):
		self.trailer = ""

	def get_country(self):
		self.country = ''
		elements = string.split(self.detail_page, '/directory/az.php3?l')
		elements[0] = ''
		delimiter = ''
		for element in elements:
			if element <> '':
				self.country = self.country + delimiter + gutils.trim(element, '>', '<')
				delimiter = ', '

	def get_rating(self):
		self.rating = gutils.strip_tags(gutils.trim(self.page, 'User-Wertung:', '</TABLE>'))
		self.rating = self.rating.replace('%', '')
		self.rating = self.rating.replace('&nbsp;', '')
		self.rating = self.rating.replace('\n', '')
		try:
			ratingint = round(float(self.rating) / 10.0)
		except:
			ratingint = 0
		self.rating = str(ratingint)

	def get_notes(self):
		self.notes = ""

class SearchPlugin(movie.SearchMovie):

	def __init__(self):
		self.original_url_search   = "http://www.zelluloid.de/suche/index.php3?qstring="
		self.translated_url_search = "http://www.zelluloid.de/suche/index.php3?qstring="
		self.encode='iso-8859-1'
		self.remove_accents = False

	def search(self,parent_window):
		self.open_search(parent_window)
		tmp = gutils.trim(self.page, "Der Suchbegriff erzielte", "</TABLE>")
		return tmp

	def get_searches(self):
		elements = string.split(self.page, "hit.php3?hit=")
		elements[0] = ''
		for element in elements:
			if element <> '':
				id = gutils.trim(element, 'movie-', '-')
				if id <> '':
					self.ids.append(id)
					self.titles.append(gutils.strip_tags(string.replace(gutils.trim(element, '>', '</A>'), '<BR>', ' - ')))

#
# Plugin Test
#
class SearchPluginTest(SearchPlugin):
	#
	# Configuration for automated tests:
	# dict { movie_id -> [ expected result count for original url, expected result count for translated url ] }
	#
	test_configuration = {
		'Rocky Balboa'		: [ 1, 1 ],
		'Die wilden Hühner'	: [ 3, 3 ]
	}

class PluginTest:
	#
	# Configuration for automated tests:
	# dict { movie_id -> dict { arribute -> value } }
	#
	# value: * True/False if attribute only should be tested for any value
	#        * or the expected value
	#
	test_configuration = {
		'2835' : { 
			'title' 			: 'Rocky Balboa',
			'o_title' 			: 'Rocky Balboa',
			'director'			: 'Sylvester Stallone',
			'plot' 				: True,
			'cast'				: 'Sylvester Stallone' + _(' as ') + 'Rocky Balboa\n\
Burt Young' + _(' as ') + 'Paulie\n\
Antonio Tarver' + _(' as ') + 'Mason Dixon\n\
Geraldine Hughes' + _(' as ') + 'Marie\n\
Milo Ventimiglia' + _(' as ') + 'Rocky Jr.\n\
Tony Burton' + _(' as ') + 'Duke\n\
A.J. Benza' + _(' as ') + 'L.C.\n\
James Francis Kelly III' + _(' as ') + 'Steps\n\
Talia Shire' + _(' as ') + 'Adrian\n\
Lou DiBella' + _(' as ') + 'Lou DiBella\n\
Mike Tyson' + _(' as ') + 'Mike Tyson\n\
Henry G. Sanders' + _(' as ') + 'Martin',
			'country'			: 'USA',
			'genre'				: 'Drama, Sport',
			'classification'	: 'ab 12',
			'studio'			: 'Chartoff-Winkler Productions, Columbia Pictures Corporation, Metro-Goldwyn-Mayer, Revolution Studios, Rogue Marble',
			'o_site'			: False,
			'site'				: 'http://www.zelluloid.de/filme/details.php3?id=2835',
			'trailer'			: False,
			'year'				: 2006,
			'notes'				: False,
			'runtime'			: 102,
			'image'				: True,
			'rating'			: 8.0
		},
		'6342' : { 
			'title' 			: 'Die wilden Hühner',
			'o_title' 			: 'Die wilden Hühner',
			'director'			: 'Vivian Naefe',
			'plot' 				: True,
			'cast'				: 'Michelle von Treuberg' + _(' as ') + 'Sprotte\n\
Lucie Hollmann' + _(' as ') + 'Frieda\n\
Paula Riemann' + _(' as ') + 'Melanie\n\
Zsa Zsa Inci Bürkle' + _(' as ') + 'Trude\n\
Jette Hering' + _(' as ') + 'Wilma\n\
Jeremy Mockridge' + _(' as ') + 'Fred\n\
Philip Wiegratz' + _(' as ') + 'Steve\n\
Martin Kurz' + _(' as ') + 'Torte\n\
Vincent Redetzki' + _(' as ') + 'Willi\n\
Veronica Ferres' + _(' as ') + 'Sprottes Mutter Sibylle\n\
Doris Schade' + _(' as ') + 'Oma Slättberg\n\
Jessica Schwarz' + _(' as ') + 'Frau Rose\n\
Benno Fürmann' + _(' as ') + 'Herr Grünbaum\n\
Axel Prahl' + _(' as ') + 'Willis Vater\n\
Lukas Steimel' + _(' as ') + 'Luki\n\
Lukas Engel' + _(' as ') + 'Titus\n\
Pino Severino Geyssen' + _(' as ') + 'Paolo\n\
Christine Rose' + _(' as ') + 'Jutta\n\
Herbert Meurer' + _(' as ') + 'Herr Feistkorn\n\
Marius Fischer' + _(' as ') + 'Bo\n\
Anya Hoffmann' + _(' as ') + 'Melanies Mutter\n\
Frank Wickermann' + _(' as ') + 'Melanies Vater\n\
Axel Häfner' + _(' as ') + 'Schrottplatzwärter\n\
Simon Gosejohann' + _(' as ') + 'junger Mann\n\
Piet Klocke' + _(' as ') + 'Junggeselle',
			'country'			: 'Deutschland',
			'genre'				: 'Kinder',
			'classification'	: 'ohne',
			'studio'			: 'Bavaria Film, Constantin Film',
			'o_site'			: False,
			'site'				: 'http://www.zelluloid.de/filme/details.php3?id=6342',
			'trailer'			: False,
			'year'				: 2006,
			'notes'				: False,
			'runtime'			: 109,
			'image'				: True,
			'rating'			: 8.0
		}
	}



# -*- coding: cp1250 -*-
__revision__ = '$Id: PluginMovieCSFD.py 12 2007-01-05 09:08:06Z blondak $'
# Copyright (c) 2005 Blondak
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

import gutils
import movie,string
import re

plugin_name = "CSFD"
plugin_description = "Cesko-Slovenska Filmova Databaze"
plugin_url = "www.csfd.cz"
plugin_language = _("Czech")
plugin_author = "Blondak"
plugin_author_email = "<blondak@neser.cz>"
plugin_version = "0.8"

class Plugin(movie.Movie):
	def __init__(self, id):
		self.movie_id = id
		self.encode = "cp1250"
		self.url = "http://www.csfd.cz/"+str(id)

	def get_image(self):
		self.image_url = re.search(r"background=\"http://img.csfd.cz/posters/([^\"]*)\"",self.page)
		if self.image_url:
			self.image_url = "http://img.csfd.cz/posters/" + gutils.strip_tags(self.image_url.group(1))
		else:
			self.image_url = ""

	def get_o_title(self):
		self.o_title = re.findall(r"/images/flag_[\d]+\.gif'[^>]*></td><td>([^<]*)",self.page)
		if len(self.o_title)>0:
			self.o_title = self.o_title[len(self.o_title)-1]
		else:
			self.o_title = ""
		if self.o_title == "":
			self.o_title = self.get_title(True)

	def get_title(self, ret=False):
		data = re.search(r"<title>([^,]*), ",self.page)
		if data:
			data = data.group(1)
		else:
			data = ""
		if ret is True:
			return data
		else:
			self.title = data

	def get_director(self):
		self.director = re.search(r"Režie:(.*)<br><b>Hrají:",self.page)
		if self.director:
			self.director = gutils.strip_tags(self.director.group(1))
		else:
			self.director = ""

	def get_year(self):
		self.year = re.search(r"<title>.*\(([\d]+)\)",self.page)
		if self.year:
			self.year = self.year.group(1)
		else:
			self.year = ""

	def get_runtime(self):
		self.runtime = re.search(r"([\d]+) min</b><BR><BR><b>Režie:",self.page)
		if self.runtime:
			self.runtime = gutils.strip_tags(self.runtime.group(1))
		else:
			self.runtime = ""

	def get_genre(self):
		self.genre = re.search(r"/images/flag_[\d]+.gif.*</table>[\s]*<br>[\s]*<b>([^&:]*)&nbsp;<br>",self.page)
		if self.genre:
			self.genre = gutils.strip_tags(self.genre.group(1))
		else:
			self.genre = ""

	def get_country(self):
		self.country = re.search(r"/images/flag_[\d]+.gif.*</table>[\s]*<br>[\s]*<b>[^&:]*&nbsp;<br>(.*), [\d]{4}, ",self.page)
		if self.country:
			self.country = gutils.strip_tags(self.country.group(1))
		else:
			self.country = ""

	def get_cast(self):
		self.cast = re.search(r"Hrají: (.*)</div><br>",self.page)
		if self.cast:
			self.cast = gutils.strip_tags(self.cast.group(1))
		else:
			self.cast = ""

	def get_plot(self):
		self.plot = gutils.strip_tags(string.replace(gutils.trim(self.page,"Obsah / Info:","</td>"),"(oficiální text distributora)",""))

	def get_site(self):
		self.site = re.search(r"href=[\"'](http://.*imdb\.com/title/[^\"']*)",self.page)
		if self.site:
			self.site = gutils.strip_tags(self.site.group(1))
		else:
			self.site = ""

	def get_trailer(self):
		self.trailer = re.search(r"<a href=\"([^\"]*)\"[^>]*>trailer<br><img src=\"http://img.csfd.cz/images/new/film/ikona_trailer",self.page)
		if self.trailer:
			self.trailer = "http://www.csfd.cz/"+gutils.strip_tags(self.trailer.group(1))

		else:
			self.trailer = ""

	def get_rating(self):
		self.rating = re.search(r"[\s]*([\d]+)%[\s]*</td>",self.page)
		if self.rating:
			self.rating = str(float(self.rating.group(1))/10)
		else:
			self.rating = ""

	def get_o_site(self):
		self.o_site = re.search(r"href=\"([^\"]*)\"[^>]*>www<br><img src=\"http://img.csfd.cz/images/new/film/ikona_www",self.page)
		if self.o_site:
			self.o_site = gutils.strip_tags(self.o_site.group(1))
		else:
			self.o_site = ""

	def get_notes(self):
		self.notes = ""

	def get_studio(self):
		self.studio = ""

	def get_classification(self):
		self.classification = ""

class SearchPlugin(movie.SearchMovie):
	def __init__(self):
		self.encode = "cp1250"
		self.original_url_search   = "http://www.csfd.cz/search_pg.php?search="
		self.translated_url_search = "http://www.csfd.cz/search_pg.php?search="

	def search(self,parent_window):
		self.open_search(parent_window)
		return self.page

	def get_searches(self):
		tmp_id = self.re_items=re.search(r"window.location.href='http://www.csfd.cz/(/film/[^']*)'",self.page)
		if tmp_id:
			self.ids.append(tmp_id.group(1))
		else:
			self.re_items=re.findall(r"href=\"(/film/[^\"]+)[^>]*>([^<]+)</a>([^<]*)",self.page)
			self.number_results = len(self.re_items)
			if (self.number_results > 0):
				for item in self.re_items:
					self.ids.append(item[0])
#					self.titles.append(gutils.convert_entities(item[1])+' '+item[2])
					self.titles.append(item[1]+' '+item[2])

